import { NavigationContainer } from '@react-navigation/native';
import { createNativeStackNavigator } from '@react-navigation/native-stack';
import { Login } from './pages/Login';
import { AccountCreation } from './pages/AccountCreation';
import DriverHome from './pages/DriverHome';
import ScheduleAvailability from './pages/ScheduleAvailability';
import PassengerHome from './pages/PassengerHome';
import TripPlanner from './pages/TripPlanner';
import { Settings } from './pages/Settings';
import DestinationSelector from './pages/DestinationSelector';
import LocalResources from './pages/LocalResources';
import Header from './components/Header'
import DateTimeSelector from './pages/DateTimeSelector';
import DriverAcceptedRequests from './pages/DriverAcceptedRequests';
import FriendsList from './pages/FriendsList';
import HeaderDriver from './components/HeaderDriver';
import AboutUs from './pages/AboutUs';
import FriendList from './pages/FriendList';
import Rating from './pages/Rating';

const StackNavigator = createNativeStackNavigator();

import { LogBox } from 'react-native';
LogBox.ignoreLogs(['Warning: ...']); // Ignore log notification by message
LogBox.ignoreAllLogs();//Ignore all log notifications

function PassengerHomePage({ navigation, route }) {
  return (
    <PassengerHome navProp={navigation} userProp={route.params.userProp}></PassengerHome> 
  )
}

function DriverHomePage({ navigation, route }) {
  return (
    <DriverHome navProp={navigation} userProp={route.params.userProp}></DriverHome> 
  )
}

function ScheduleAvailabilityPage({ navigation, route }) {
  return (
      <ScheduleAvailability navProp={navigation} userProp={route.params.userProp}></ScheduleAvailability>
  )
}

function DriverAcceptedRequestsPage({ navigation, route }) {
  return (
    <DriverAcceptedRequests navProp={navigation} userProp={route.params.userProp}></DriverAcceptedRequests>
  )
}

function LoginPage({ navigation }) {
    return (
      <Login navProp={navigation}></Login>
    );
}

function AccountCreationPage({ navigation, route }) {
    return (
        <AccountCreation navProp={navigation} accountProp={route.params.accountType}></AccountCreation>
    );
}

function SettingsPage({navigation, route}) {
    return (
        <Settings navProp={navigation} /*accountProp={route.params.accountType}*/ userProp={route.params.userProp}></Settings>
    );
}
function DateTimeSelectorPage({navigation, route}){
  return (
    <DateTimeSelector navProp={navigation} userProp={route.params.userProp} destinationProp={route.params.destinationTo} startingLocationProp={route.params.startLocation} currentLatitudeProp={route.params.latitude} currentLongitudeProp={route.params.longitude}></DateTimeSelector>
  );
}

function DestinationSelectorPage({navigation, route}) {
  return (
    <DestinationSelector navProp={navigation} userProp={route.params.userProp} latitudeProp={route.params.latitude} longitudeProp={route.params.longitude}></DestinationSelector>
  );
}

function LocalResourcesPage({navigation, route }) {
  return(
    <LocalResources navProp={navigation} userProp={route.params.userProp}></LocalResources>
  );
}

function TripPlannerPage({navigation, route}) {
  return(
    <TripPlanner navProp={navigation} 
      userProp={route.params.userProp} 
      dateProp={route.params.formattedDate} 
      timeProp={route.params.formattedTime} 
      destinationProp={route.params.destinationTo} 
      startingLocationProp={route.params.startLocation} 
      currentLatitudeProp={route.params.latitude} 
      currentLongitudeProp={route.params.longitude} 
    />
  );
}


function FriendsListPage({ navigation }) {
  return (
    <FriendsList navProp={navigation}></FriendsList> 
  )
}

function FriendListPage({ navigation, route }) {
  return (
    <FriendList navProp={navigation} userProp={route.params.userProp}></FriendList>
  )
}

function AboutUsPage({ navigation }) {
  return(
    <AboutUs navProp={navigation}></AboutUs>
  )
}

function RatingPage({ navigation, route }) {
    return (
        <Rating navProp={navigation} userProp={'4791234567'}></Rating>
    )
}

export default function App() {
    return (
        <NavigationContainer>
            <StackNavigator.Navigator>

                <StackNavigator.Screen 
                  name="Login" 
                  component={LoginPage}
                  options={{ headerShown: false }}
                />

                <StackNavigator.Screen 
                  name="Account Creation" 
                  component={AccountCreationPage} 
                  options={{ headerShown: false }}
                />
                
                <StackNavigator.Screen
                  name="Passenger Home"
                  component={PassengerHomePage}
                  options={({ navigation }) => ({
                      header: () => <Header navProp={navigation} pageTitle={'Home'} />
                  })
                  }
                />

                <StackNavigator.Screen 
                  name="Driver Home" 
                  component={DriverHomePage} 
                  options = {({navigation}) => ({
                    header: () => <HeaderDriver navProp={navigation} pageTitle={'Home'} />
                  })
                    } 
                />

                <StackNavigator.Screen 
                  name="Driver Schedule Availability" 
                  component={ScheduleAvailabilityPage} 
                  options={({ navigation }) => ({
                    header: () => <HeaderDriver navProp={navigation} pageTitle={'Scheduler'} />
                    })
                    }
                />

                <StackNavigator.Screen
                  name="Driver Accepted Requests"
                  component={DriverAcceptedRequestsPage}
                  options={({ navigation }) => ({
                    header: () => <HeaderDriver navProp={navigation} pageTitle={'Accepted Requests'} />
                  })
                  } 
                />

                <StackNavigator.Screen 
                  name="Trip Planner"
                  component={TripPlannerPage}
                  options = {({navigation}) => ({
                    header: () => <Header navProp={navigation} pageTitle={'Trip Planner'} />
                    })
                    }
                />
                
                <StackNavigator.Screen
                  name="Destination Selector"
                  component={DestinationSelectorPage}
                  options={({ navigation }) => ({
                    header: () => <Header navProp={navigation} pageTitle={'Destination'} />
                    })
                    }
                />

                <StackNavigator.Screen
                  name="Settings"
                  component={SettingsPage}
                  options={{ headerShown: false }}
                />

                <StackNavigator.Screen 
                  name="About Us"
                  component={AboutUsPage}
                  options={{ headerShown: false }}
                />

                <StackNavigator.Screen 
                  name="Friend List"
                  component={FriendListPage}
                  options={{ headerShown: false }}
                />

                <StackNavigator.Screen
                  name="Date Time Selector" 
                  component={DateTimeSelectorPage} 
                  options = {({navigation}) => ({
                    header: () => <Header navProp={navigation} pageTitle={'Date Time Selector'} />
                    })
                  }
                />

                <StackNavigator.Screen
                  name="Local Resources"
                  component={LocalResourcesPage}
                  options={({navigation}) => ({
                    header: () => <Header navProp={navigation} pageTitle={'Local Resources'} />
                  })
                  }
                />

                <StackNavigator.Screen 
                  name="Friends List" 
                  component={FriendsListPage}
                  options={({ navigation }) => ({
                      header: () => <Header pageTitle={'Friends List'} />
                  })
                  }
                /> 

                <StackNavigator.Screen
                    name="Rating"
                    component={RatingPage}
                    options={{ headerShown: false }}
                />
                
            </StackNavigator.Navigator>
        </NavigationContainer>
    );
}
