import {React, useState } from 'react';
import { Text, View, Image, TouchableOpacity, SafeAreaView, Modal, Keyboard } from 'react-native';
import Styles from '../shared/styles/Styles';
import { MaterialIcons, FontAwesome, Fontisto } from '@expo/vector-icons';

export default function Header(props) {
    const [modalVisible, setModalVisible] = useState(false);
    let userProp = props.userProp;
    let pageTitle = props.pageTitle;

    return (
        <SafeAreaView style={Styles.header}>
            <Modal
                // animationType="slide"
                transparent={true}
                visible={modalVisible}
                onRequestClose={() => {
                    setModalVisible(!modalVisible);
                }}
                >
                <TouchableOpacity style={{ flex: 1, justifyContent: "flex-end", alignItems: "flex-start", backgroundColor: '#00000044'}} activeOpacity={1} onPress={() => {Keyboard.dismiss()}}>
                    <View style={Styles.headerModal}>
                        <View style={{flex: 0.5, width: '100%', alignItems: 'flex-end'}}>
                            <TouchableOpacity onPress={() => setModalVisible(!modalVisible)} style={{flex: 1, marginRight: 12}}>
                                <MaterialIcons name="close" size={32} />
                            </TouchableOpacity>
                        </View>
                        <View style={[Styles.headerModalButtons, { borderTopWidth: 0}]}>
                            <TouchableOpacity onPress={() => {props.navProp.navigate("Passenger Home",{userProp: pageTitle}), setModalVisible(!modalVisible)}} style={{flex: 1, justifyContent: 'center'}} >
                                <Text style={Styles.headerModalButtonsText}>Home</Text>
                            </TouchableOpacity>
                        </View>
                        <View style={Styles.headerModalButtons}>
                            <TouchableOpacity onPress={() => {props.navProp.navigate("Settings", {userProp: pageTitle}), setModalVisible(!modalVisible)}} style={{flex: 1, justifyContent: 'center'}} >
                                <Text style={Styles.headerModalButtonsText}>Profile</Text>
                            </TouchableOpacity>
                        </View>
                        {/* <View style={Styles.headerModalButtons}>
                            <TouchableOpacity onPress={() => {alert("Page not implemented yet."), setModalVisible(!modalVisible)}} style={{flex: 1, justifyContent: 'center'}} >
                                <Text style={Styles.headerModalButtonsText}>Rides</Text>
                            </TouchableOpacity>
                        </View> */}
                        <View style={Styles.headerModalButtons}>
                            <TouchableOpacity onPress={() => {props.navProp.navigate("Friend List", {userProp: pageTitle}), setModalVisible(!modalVisible)}} style={{flex: 1, justifyContent: 'center'}} >
                                <Text style={Styles.headerModalButtonsText}>Friends</Text>
                            </TouchableOpacity>
                        </View>

                        <View style={{flex: 5}}>
                        </View>

                        <View style={Styles.headerModalButtons}>
                            <TouchableOpacity onPress={() => {props.navProp.navigate("About Us"), setModalVisible(!modalVisible)}} style={{flex: 1, justifyContent: 'center'}} >
                                <Text style={Styles.headerModalButtonsText}>About Us</Text>
                            </TouchableOpacity>
                        </View>
                        <View style={Styles.headerModalButtons}>
                            <TouchableOpacity onPress={() => {props.navProp.navigate("Login"), setModalVisible(!modalVisible)}} style={{flex: 1, justifyContent: 'center', flexDirection: 'row', justifyContent: 'flex-start', marginTop: 12 }} >
                                <Text style={[Styles.headerModalButtonsText, { marginRight: 12}]}>Sign Out</Text>
                                <FontAwesome name="sign-out" size={24} color="#1b3469" />
                            </TouchableOpacity>
                        </View>
                        <View style={{flex: 1}}>
                        </View>
                        
                    </View>
                </TouchableOpacity>
            </Modal>


            <View style={Styles.header}>
                <View style={{flex: 1, alignItems: 'flex-start', marginLeft: 2}}>
                    <TouchableOpacity onPress={() => setModalVisible(true)}>
                        <Fontisto name="nav-icon-grid-a" size={28} color="black" />
                    </TouchableOpacity>    
                </View>
                <View style={{flex: 1, alignItems: 'flex-end'}}>
                    <TouchableOpacity onPress={() => props.navProp.navigate("Settings", {userProp: pageTitle})}>
                        <MaterialIcons name="account-circle" size={40} color="black" />
                    </TouchableOpacity>
                </View>
            </View>
        </SafeAreaView>
    )
}