// Author: Alan Torres
// Help button component

import React, {useState} from 'react';
import { Linking, Platform, View, Text, Pressable, Modal, Keyboard, TouchableOpacity, TextInput, Image } from 'react-native';
import Divider from 'react-native-divider';
import qs from 'qs';
import Styles from '../../shared/styles/Styles';
// TO USE: Add ' <HelpModal />' to any page.

export default function HelpModal() {
    const [modalVisible, setModalVisible] = useState(false);
    const [subjectMail, setSubject] = useState('Subject Line');
    const [problemMail, setProblem] = useState('What is the problem?');

    async function sendEmail() {

        if(subjectMail.length == 0 || subjectMail == 'Subject Line'){
            alert("Please provide a subject line.");
            return;
        }
        else if(problemMail.length == 0 || problemMail == 'What is the problem?'){
            alert("Please provide more details about the problem.");
            return;
        }

        let finalSubject = subjectMail + " | MAGIC HELP EMAIL";
        let to = 'magic_team6@outlook.com';
        let url = `mailto:${to}`;
        const query = qs.stringify({
            subject: finalSubject,
            body: problemMail
        });

        if(query.length){ url += `?${query}`; }

        const canOpenWithLink = await Linking.canOpenURL(url);
        if(!canOpenWithLink){ throw new Error("URL did not work.") }

        return Linking.openURL(url);
    }

    makeCall = () => {
        let phoneNumber = '';
        if (Platform.OS == 'android'){
            phoneNumber = 'tel:${1234567890}';
        }
        else{
            phoneNumber = 'telprompt:${1234567890}';
        }
        Linking.openURL(phoneNumber);
    };

    return (
      <View>
        <Modal
        animationType="slide"
        transparent={true}
        visible={modalVisible}
        onRequestClose={() => {
            this.setModalVisible(!modalVisible);
        }}
        >
        
        <TouchableOpacity style={Styles.centeredView} activeOpacity={1} onPress={() => {Keyboard.dismiss()}}>
            <View style={Styles.modalView}>
                <View style={Styles.topModalTextCluster}>
                    <Text style={Styles.modalText}>Having a problem with the app?</Text>
                    <Text style={Styles.modalText}>Call and leave a voicemail:</Text>
                </View>
                <TouchableOpacity 
                style={Styles.HelpCallButton}
                onPress={makeCall}
                >
                    <Text style={Styles.ButtonText}>Call MAGIC</Text>
                    <TouchableOpacity onPress={makeCall}>
                        <Image style={Styles.PhoneIcon} 
                        source={require('../../assets/phoneIcon.png')}>
                        </Image>
                    </TouchableOpacity> 
                </TouchableOpacity>
                <View style={Styles.middleModalTextCluster}>
                    <Divider borderColor="#466682" color="#466682" orientation="center">OR</Divider>
                    <Text style={Styles.modalText}>Send an Email below:</Text>
                </View>
                <View style={Styles.modalTopCluster}>
                    <View style={Styles.modalTopClusterTopTextInput}>
                        <TextInput 
                            style={Styles.modalSingleline}
                            placeholder='Subject of problem'
                            placeholderTextColor={'#b6bbcf'}
                            returnKeyType='done'
                            onChangeText={(val) => setSubject(val)}
                            onSubmitEditing={() => {Keyboard.dismiss()}}
                        />
                    </View>
                    <View style={Styles.modalTopClusterBottomTextInput}>
                        <TextInput
                            multiline={true}
                            numberOfLines={3}
                            placeholder='What is the problem?'
                            placeholderTextColor={'#b6bbcf'}
                            onChangeText={(val) => setProblem(val)}
                            style={Styles.modalMultiline}
                        />
                    </View>
                </View>
        
                <View style={Styles.buttonBottomCluster}>
                    <Pressable 
                    style={[Styles.button, {backgroundColor: '#4797ff'}]} 
                    onPress={() =>{ sendEmail(), setModalVisible(!modalVisible) }} // This is where Sai's implementation will go to send emails
                    >
                        <Text style={[Styles.textStyle]}>Send Email</Text>
                    </Pressable>
        
                    <Pressable style={[Styles.button, Styles.buttonClose]} onPress={() => setModalVisible(!modalVisible)} >
                        <Text style={Styles.textStyle}>Close</Text>
                    </Pressable>
                </View>
            </View>
        </TouchableOpacity>
        </Modal>   

        <View>
            <TouchableOpacity style={Styles.helpButton} onPress={() => setModalVisible(true)}>
              <Text style={Styles.helpButtonText}>Help </Text>
              <Image style={Styles.helpIcon} source={require('../../assets/help.png')}></Image>
            </TouchableOpacity>
        </View>

    </View>
    )
  ;}


