//by Emily Lea
//This is a button that, when clicked, adds details of a confirmed transportation request to a person's calendar
//details passed in for drivers: passenger first and last names, passenger phone, date, time, 
//details passed in for passengers: driver first and last, driver phone, date, time

import { Text, View, TouchableOpacity, TextInput, StatusBar, KeyboardAvoidingView, Platform, Pressable } from 'react-native';
import React, { Component } from 'react';
import Styles from '../../shared/styles/Styles';
import * as Calendar from 'expo-calendar';
//to use: <SyncToCalendar phone="" firstName="" lastName="" date="" time=""></SyncToCalendar>

export class SyncToCalendar extends Component {
    constructor(props) {
        super(props);
        //temporarily hard-coded these for testing 
        this.phone = props.phone;
        this.firstName = props.firstName;
        this.lastName = props.lastName;
        this.date = props.date;
        this.time = props.time;
        this.state = {
            magicCalendar: "",
        };
    }

    //request permissions; find or create MAGIC calendar
    async componentDidMount() {
        const calendarPermissions = await Calendar.requestCalendarPermissionsAsync();
        var calendarSource = "";
        if (calendarPermissions.status == "granted") {
            //request Reminders permissions for iOS
            if (Platform.OS == "ios") {
                const remindersPermissions = await Calendar.requestRemindersPermissionsAsync();
            }
            //check if MAGIC calendar exists
            const calendars = await Calendar.getCalendarsAsync();
            const calendar = calendars.filter(cal => cal.title == "MAGIC Calendar");
            if (calendar.length > 0) {
                calendarSource = calendar[0].source;
            }
            //get sources and id's for Android and iOS calendars
            else {
                if (Platform.OS == "android") {
                    calendarSource = {isLocalAccount: true, name: "MAGIC Calendar"};
                }
                else {
                    calendarSource = calendars[0].source;
                    calendarSourceId = calendars[0].source.id;
                }
                //create a new MAGIC calendar
                const newCalendar = await Calendar.createCalendarAsync({
                    title: 'MAGIC Calendar',
                    color: 'blue',
                    entityType: Calendar.EntityTypes.EVENT,
                    sourceId: calendarSource.id,
                    source: calendarSource,
                    name: 'MAGIC Calendar',
                    ownerAccount: 'personal',
                    accessLevel: Calendar.CalendarAccessLevel.OWNER
                });
                calendar = newCalendar;
            }
            //set the magicCalendar state
            this.setState({ magicCalendar: calendar });
        }
    }

    _addToCalendar = async () => {
        //id of MAGIC calendar
        var id = this.state.magicCalendar[0].id.toString();
        //date prop
        var splitDate = this.date.split('/');
        var month = parseInt(splitDate[0]) - 1;
        var day = parseInt(splitDate[1]);
        var year = parseInt('20' + splitDate[2]);
        //time prop
        var splitTime = this.time.split(' ');
        var hourMin = splitTime[0].split(':');
        var hour = parseInt(hourMin[0]);
        var minute = parseInt(hourMin[1]);
        if (splitTime[1] == "AM") {
            if (hour == 12) {
                hour = 0;
            }
        }
        if (splitTime[1] == "PM") {
            if (hour != 12) {
                hour = hour + 12;
            }
        }
        //start of calendar event
        var eventStart = new Date(year, month, day, hour, minute);
        var eventStartString = eventStart.toISOString();
        //end of calendar event (+1hr)
        hour = hour + 1;
        if (hour > 24) {
            hour = 0;
        }
        var eventEnd = new Date(year, month, day, hour, minute);
        var eventEndString = eventEnd.toISOString();
        //create and add the event to the MAGIC calendar
        var notesString = this.firstName + " " + this.lastName;
        const newEvent = await Calendar.createEventAsync(id, { title: 'Scheduled Transportation', notes: notesString, startDate: eventStartString, endDate: eventEndString });
    }
    //styling can be updated once this component is added to confirmation/denial UI for transportation requests
    render() {
        return (
            <View>
                <TouchableOpacity style={{
                    backgroundColor: '#4797ff',
                    borderRadius: 8,
                    //width: '75%',
                    //height: 'auto',
                    padding: 8,
                    justifyContent: 'center',
                    alignItems: 'center'
                }}
                    onPress={() => this._addToCalendar()}>
                    <Text style={Styles.SigninButtonText}>Add to Calendar</Text>
                </TouchableOpacity>
            </View>
        );
    }

}