// Author: Alan Torres
// Component used by ScheduleAvailability.js page.

import React, {useState} from 'react';
import {View, Text, TouchableOpacity, Platform, Alert} from 'react-native';
import DateTimePicker from '@react-native-community/datetimepicker';
import Styles from '../../shared/styles/Styles';

export default function WeekDayScheduler(props) {
    let driverPhoneNumber = props.driverPhoneNumber;

    const { dayOfWeek, startTime, endTime} = props;

    // variables to determine background and text color of component
    let startDisplayTime = ((startTime.getHours() + 11) % 12 + 1)+":"+startTime.getMinutes()+((startTime.getHours())>=12 ? "PM" : "AM");
    let endDisplayTime = ((endTime.getHours()+11)%12+1)+":"+endTime.getMinutes()+((endTime.getHours())>=12 ? "PM" : "AM");
    let backgroundColorOfDay = (startDisplayTime == endDisplayTime) ? '#ebebf0' : '#ffffff'; 
    let textColorOfDay = (startDisplayTime == endDisplayTime) ? '#a0abba' : '#5e7eff';
    let availableTime;
    const [bckColor, setBckColor] = useState(backgroundColorOfDay);
    const [txtColor, setTxtColor] = useState(textColorOfDay);
    const [startDate, setDate] = useState(startTime);
    const [endDate, setDate2] = useState(endTime);
    const [isStartPickerShow, setIsStartPickerShow] = useState(false);
    const [isEndPickerShow, setIsEndPickerShow] = useState(false);
    const [timeUpdated, setTimeUpdated] = useState(false);

    // for android: used to display time picker for end time
    const showEndPicker = () => {
        setIsEndPickerShow(true);
    }
    // for android: used to display time picker for start time
    const showStartPicker = () => {
        setIsStartPickerShow(true);
    };

    // changes start time
    const changeStart = (event, selectedDate) => {
        const currentDate = selectedDate || startDate;
        setIsStartPickerShow(false);
        setDate(currentDate);
        setTimeUpdated(true);

        availableTime = Math.round(100*((startDate - endDate) / (1000 * 60 * 60)))/100;
    };

    // changes end time
    const changeEnd = (event, selectedDate) => {
        const currentDate = selectedDate || endDate;
        setIsEndPickerShow(false);
        setDate2(currentDate);
        setTimeUpdated(true);

        availableTime = Math.round(100*((startDate - endDate) / (1000 * 60 * 60)))/100;
    };

    // updates parent (ScheduleAvailability.js)
    const updateTimeChanges = () => {
        if(availableTime < 0){
            Alert.alert("Cannot update schedule","Make sure you have entered a valid schedule.");
        }
        else{
            if(availableTime == 0) {
                console.log(((startDate.getHours()+11)%12+1)+":"+((startDate.getMinutes()).toString().length ==1?('0'+startDate.getMinutes()):(startDate.getMinutes()))+((startDate.getHours())>=12?" PM":" AM") + '-' + ((endDate.getHours()+11)%12+1)+":"+((endDate.getMinutes()).toString().length ==1?('0'+endDate.getMinutes()):(endDate.getMinutes()))+((endDate.getHours())>=12?" PM":" AM"));
                setBckColor('#ebebf0');
                setTxtColor('#a0abba');
                setTimeUpdated(false);
            }
            else{
                setTimeUpdated(false);
                setBckColor('#ffffff');
                setTxtColor('#3d8eff');
            }
            // console.log(((startDate.getHours()+11)%12+1)+":"+((startDate.getMinutes()).toString().length ==1?('0'+startDate.getMinutes()):(startDate.getMinutes()))+((startDate.getHours())>=12?" PM":" AM") + '-' + ((endDate.getHours()+11)%12+1)+":"+((endDate.getMinutes()).toString().length ==1?('0'+endDate.getMinutes()):(endDate.getMinutes()))+((endDate.getHours())>=12?" PM":" AM"));
            // update parent with new start/end times
            props.changeStartDate(startDate); // send new startDate up
            props.changeEndDate(endDate); // send new endDate up

            // update database
            let newDBstartTime = ((startDate.getHours()+11)%12+1)+":"+((startDate.getMinutes()).toString().length ==1?('0'+startDate.getMinutes()):(startDate.getMinutes()))+((startDate.getHours())>=12?" PM":" AM")
            let newDBendTime = ((endDate.getHours()+11)%12+1)+":"+((endDate.getMinutes()).toString().length ==1?('0'+endDate.getMinutes()):(endDate.getMinutes()))+((endDate.getHours())>=12?" PM":" AM");
            let timeRangeTime = newDBstartTime+"-"+newDBendTime;
            console.log(timeRangeTime);

            var newDatabaseTimes = {
                "phone": driverPhoneNumber,
                "day": dayOfWeek,
                "time_range": timeRangeTime,    
            };
            let specifications = {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json;charset=utf-8'
                },
                body: JSON.stringify(newDatabaseTimes)
            }
            fetch("https://magicdjangoapp.herokuapp.com/driverschedule/schedule/", specifications)
            .then(response => response.json())
            .then(jsonResponse => {
                console.log(jsonResponse);
            })
            .catch(error => console.log(error));
        }
    }

    // function to get total available time from start to end
    function getDifferenceInHours(date1, date2) {
        availableTime = Math.round(100*((date2 - date1) / (1000 * 60 * 60)))/100;
        if(availableTime == 0){
            return "Not scheduled.";
        }
        else if (availableTime > 0){
            return "Your total available time is " + availableTime + " hour(s)";
        }
        else
            return "Oops! End time must come before start.";
    };

    return (
    <View style={[Styles.weekDayContainer, {backgroundColor: bckColor}]}>
        <View style={Styles.weekDayContainerQuadrant}>
            <View style={Styles.weekDayContainerQuadrantHalf}>
                <Text style={{color: txtColor, fontWeight: '700', fontSize: 20, lineHeight: 24, justifyContent: 'center'}}>{dayOfWeek}</Text>
            </View>
            {timeUpdated && (
                <View style={[Styles.weekDayContainerQuadrantHalf, {alignItems: 'flex-end'}]}>
                <View style={{width: '50%', backgroundColor: '#3b79ff', padding: 4, borderRadius: 4}}>
                    <TouchableOpacity onPress={updateTimeChanges}>
                        <Text style={{textAlign: 'center', fontWeight: '700', color: 'whitesmoke'}}>Update</Text>
                    </TouchableOpacity>
                </View>
            </View>
            )}
        </View>

        <View style={Styles.weekDayContainerQuadrant}>

            <View style={Styles.weekDayContainerQuadrantHalf}>
                <Text style={{color: txtColor, fontWeight: '500', fontSize: 16}}>Start </Text>
            </View>

            {Platform.OS == 'android' && (
            <View style={[Styles.weekDayContainerQuadrantHalf, { alignItems: 'flex-end', flexDirection: 'row'}]}>
                <View style={{flex: 3}}>
                    <Text style={{fontSize: 18, fontWeight: '600', color: txtColor, textAlign: 'right'}}>{((startDate.getHours()+11)%12+1)+":"+((startDate.getMinutes()).toString().length ==1?('0'+startDate.getMinutes()):(startDate.getMinutes()))+((startDate.getHours())>=12?" PM":" AM")}</Text>
                </View>
                <TouchableOpacity onPress={showStartPicker} style={{flex: 1}}>
                    <Text style={{width: '100%', flex: 1, color: '#5e7eff', textAlign: 'right', textAlignVertical: 'center'}}>Edit</Text>
                </TouchableOpacity>
            </View>
            )}

            {Platform.OS == 'ios' && (
                <View style={{flex: 2}}>
                <DateTimePicker
                testID="startDate"
                value={startDate}
                mode='time'
                is24Hour={true}
                display="default"
                confirmBtnText="Confirm"
                cancelBtnText="Cancel"
                onChange={changeStart}
                />
            </View>
            )}

            {isStartPickerShow && (
                <View style={{flex: 2}}>
                <DateTimePicker
                testID="startDate"
                value={startDate}
                mode='time'
                is24Hour={true}
                display="default"
                confirmBtnText="Confirm"
                cancelBtnText="Cancel"        
                onChange={changeStart}
                />
                </View> 
            )}
        </View>

        <View style={{ borderTopColor: '#e0e0e0', borderTopWidth: 0.75}} />

        <View style={Styles.weekDayContainerQuadrant}>
            <View style={Styles.weekDayContainerQuadrantHalf}>
                <Text style={{color: txtColor, fontWeight: '500', fontSize: 16}}>End </Text>
            </View>    

            {Platform.OS == 'android' && (
            <View style={[Styles.weekDayContainerQuadrantHalf, {alignItems: 'flex-end', flexDirection: 'row'}]}>
                <View style={{flex: 3}}>
                    <Text style={{fontSize: 18, fontWeight: '600', color: txtColor, textAlign: 'right' }}>{((endDate.getHours()+11)%12+1)+":"+((endDate.getMinutes()).toString().length ==1?('0'+endDate.getMinutes()):(endDate.getMinutes()))+((endDate.getHours())>=12?" PM":" AM")}</Text>
                </View>
                <TouchableOpacity onPress={showEndPicker} style={{ flex: 1}}>
                    <Text style={{width: '100%', flex: 1, color: '#5e7eff', textAlign: 'right', textAlignVertical: 'center'}}>Edit</Text>
                </TouchableOpacity>
            </View>
            )}
            
            {Platform.OS == 'ios' && (
            <View style={{flex: 2}}>
                <DateTimePicker
                testID="endDate"
                value={endDate}
                mode='time'
                is24Hour={true}
                display="default"
                confirmBtnText="Confirm"
                cancelBtnText="Cancel"        
                onChange={changeEnd}
                />
                </View>
            )}


            {isEndPickerShow && (
                <View style={{flex: 2}}>
                <DateTimePicker
                testID="endDate"
                value={endDate}
                mode='time'
                is24Hour={true}
                display="default"
                confirmBtnText="Confirm"
                cancelBtnText="Cancel"        
                onChange={changeEnd}
                />
                </View>    
            )}
        </View>

        <View style={Styles.weekDayContainerQuadrant}>
            <Text style={{color: txtColor, fontWeight: '400'}}>{getDifferenceInHours(startDate, endDate)}</Text>
        </View> 

    </View>

    );
}