//by Emily Lea
//Passenger acct: first name, last name, home address, email address, phone number, photo, password, next button
//Driver acct: first name, last name, email address, password, phone number, plate number, make, model, wheelchair accessible, photo
//Pass in a prop from the login screen indicating whether to sign up as a driver or a passenger

import { Text, View, TextInput, ScrollView, Pressable, Image } from 'react-native';
import React, { Component } from 'react';
import Checkbox from '../components/Checkbox/index';
import UploadImage from '../components/UploadImage/UploadImage';
import Styles from '../shared/styles/Styles';
import * as Device from 'expo-device';
import * as Notifications from 'expo-notifications';

export class AccountCreation extends Component{
    constructor(props) {
        super(props);
        this.accountType = props.accountProp;
        this.CheckboxElement = React.createRef();
        this.ImageSelectorElement = React.createRef();
        this.state = {
            token: ""
        };
    }

    //get the user's Expo token
    async componentDidMount() {
        const generated_token = (await Notifications.getExpoPushTokenAsync()).data;;
        this.setState({ token: generated_token });
        console.log(this.state.token);
    }

    render() {
        var passengerAccountInfo = {
            "first_name": "",
            "last_name": "",
            "home_address": "",
            "email_address": "",
            "phone": "",
            "password": ""
        };

        var passengerTextFields = {
            "first_name": "First Name",
            "last_name": "Last Name",
            "home_address": "Home Address",
            "email_address": "Email Address",
            "phone": "Phone",
            "password": "Password"
        };

        var driverAccountInfo = {
            "first_name": "",
            "last_name": "",
            "email_address": "",
            "phone": "",
            "password": "",
            "plate_number": "",
            "vehicle_make": "",
            "vehicle_model": ""
        };

        var driverTextFields = {
            "first_name": "First Name",
            "last_name": "Last Name",
            "email_address": "Email Address",
            "phone": "Phone",
            "password": "Password",
            "plate_number": "License Plate Number",
            "vehicle_make": "Vehicle Make",
            "vehicle_model": "Vehicle Model"
        };

        var dictionary;
        var textFields;
        if (this.accountType == "driver") {
            dictionary = driverAccountInfo;
            textFields = driverTextFields;
        }
        if (this.accountType == "passenger") {
            dictionary = passengerAccountInfo;
            textFields = passengerTextFields;
        }
        dictionary["token"] = this.state.token;
        //store the user's information in the database and navigate to the home page
        function submitAccountInformation(textFields, dictionary, checkboxRef, imageSelectorRef, nav) {
            var invalidFields = "";
            var homePageName;
            //require the driver's photo if it's not been uploaded
            if ((dictionary == driverAccountInfo) && (imageSelectorRef.current == null)) {
                invalidFields = invalidFields.concat("\n" + "Photo");
            }
            //find values that haven't been entered
            for (var key in dictionary) {
                if (dictionary[key] == "") {
                    invalidFields = invalidFields.concat("\n" + textFields[key]);
                }
            }
            if (invalidFields != "") {
                alert("The following information is required to create an account:" + invalidFields);
            }
            else {
                //driver account
                if (dictionary == driverAccountInfo) {
                    //get the photo
                    dictionary["uri"] = imageSelectorRef.current;
                    //get the wheelchair_accessible value
                    if (checkboxRef.current) {//ref.current is the value of the checkbox
                        dictionary["wheelchair_accessible"] = "yes";
                    }
                    else {
                        dictionary["wheelchair_accessible"] = "no";
                    }
                    dictionary["driver_or_passenger"] = "driver"
                    homePageName = "Driver Home"
                }
                //passenger account
                if (dictionary == passengerAccountInfo) {
                    //get the image ref or set it to empty
                    if (imageSelectorRef.current != null) {
                        dictionary["uri"] = imageSelectorRef.current;
                    }
                    else {
                        dictionary["uri"] = "";
                    }
                    dictionary["driver_or_passenger"] = "passenger"
                    homePageName = "Passenger Home"
                }
                //fetch API call
                let specifications = {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json;charset=utf-8'
                    },
                    body: JSON.stringify(dictionary)
                }
                fetch("https://magicdjangoapp.herokuapp.com/users/new_user/", specifications)
                    .then(response => response.json())
                    .then(jsonResponse => {
                        if (jsonResponse == "This phone number is associated with an existing account.") {
                            alert(jsonResponse)
                        }
                        else {
                            //navigate to the home page
                            nav.navigate(homePageName, { accountType: dictionary["driver_or_passenger"], userProp: dictionary["phone"] });

                        }
                    })
                    .catch(error => console.log(error))
            }
        }

        //forwardRef is passed into Checkbox to get the checkbox's state
        function needsCheckbox(accountType, boxLabel, dictionary, ref) {
            if (accountType == "driver") {
                ref.current = false;
                dictionary["wheelchair_accessible"] = "no"
                return (
                    <Checkbox forwardRef={ref} boxLabel={boxLabel}></Checkbox>
                )
            }
        }

        return (
            <View style={Styles.general}>
                <ScrollView style={{ width: '100%' }} showsVerticalScrollIndicator={false}>
                    <View style={{ alignItems: 'center'}}>
                        <View style={{ width: '85%'}}>
                            <View style={{marginBottom: 100}}></View>
                                <Text style={{ fontSize: 20, fontWeight: '500', marginBottom: 20 }}>Click the circle below to upload an image of yourself:</Text>
                                <View style={{ width: '100%', alignItems: 'center'}}>
                                    <UploadImage accountType={this.accountType} forwardRef={this.ImageSelectorElement}></UploadImage>
                                </View>
                                <Text style={{ fontSize: 20, fontWeight: '500', marginVertical: 20 }}>Personal Information:</Text>
                                {
                                    Object.entries(dictionary).map(([key, value]) => {
                                        if (key != "wheelchair_accessible" && key != "token") {
                                            return (
                                                <View key={key}>
                                                    <TextInput
                                                        onChangeText={(text) => dictionary[key] = text}
                                                        style={Styles.TextInputs}
                                                        placeholder={textFields[key]}
                                                        placeholderTextColor='#8ba2c4'>
                                                    </TextInput>
                                                </View>
                                            )
                                        }
                                    }
                                    )
                                }
                                <View style={Styles.NextButtonContainer}>
                                    <View style={Styles.WheelChairAccessibleBox}>
                                        {needsCheckbox(this.accountType, "Wheelchair Accessible: ", dictionary, this.CheckboxElement)}
                                    </View>
                                <View style={{ width: '100%', left: 0 }}>
                                    <Pressable style={Styles.NextButtonPressable} onPress={() => submitAccountInformation(textFields, dictionary, this.CheckboxElement, this.ImageSelectorElement, this.props.navProp)}><Text style={Styles.NextButtonText}>Next</Text></Pressable>
                                    </View>
                                </View>
                                <View style={{marginBottom: 100}}></View>
                        </View>
                    </View>
                </ScrollView>
            </View>
        );
    }
}