//by Emily Lea
//This is the second page in the trip planning process.
import {Text, View, ScrollView, Pressable, TextInput, TouchableOpacity } from 'react-native';
import React, { useState } from 'react';
import CalendarPicker from 'react-native-calendar-picker';
import DateTimePicker from '@react-native-community/datetimepicker';
import Styles from '../shared/styles/Styles';
import Header from '../components/Header';
import { useEffect } from 'react/cjs/react.production.min';

export default function DateTimeSelector(props) {
    
    const [date, setDate] = useState(null);
    const [time, setTime] = useState(new Date());
    const [isTimePickerShow, setIsTimePickerShow] = useState(false);
    
    let hour = time.getHours();
    let minute = time.getMinutes();
    let label = hour>=12 ? "PM" : "AM";
    let displayMinute = minute.toString().length==1 ? ('0'+minute) : (minute);
    let displayTime = ((hour + 11) % 12 + 1) + ":" + displayMinute + " " + label;
    let displayDate = (date == null) ? new Date() : new Date(date);
    let destinationTo = props.destinationProp;
    let startingLocation = props.startingLocationProp;
    let latitudeProp = props.currentLatitudeProp;
    let longitudeProp = props.currentLongitudeProp;

    var formattedDate;
    var formattedTime;

    //for android: show time picker
    const showTimePicker = () => {
        setIsTimePickerShow(true);
    };

    //update time that the user wants
    const changeTime = (event, selectedDate) => {
        const currentTime = selectedDate || time;
        setIsTimePickerShow(false);
        setTime(currentTime);
    };

    //get today's date and the date six months from now
    var today = new Date();
    var sixMonthsLater = new Date();
    sixMonthsLater.setMonth(today.getMonth() + 6);

    //save the desired date and time of transportation
    function submitDateAndTime(date, hour, minute, label) {
        if (date == null) {
            date = new Date();
        }
        else {
            date = new Date(date)
        }
        formattedDate = date.toLocaleDateString();

        var dd = String(date.getDate()).padStart(2, '0');
        var mm = String(date.getMonth() + 1).padStart(2, '0');
        var yy = date.getFullYear().toString();
        let today = mm + '/' + dd + '/' + yy[2]+yy[3];
        formattedDate=today;
        hour = ((hour + 11) % 12 + 1);
        formattedTime = hour + ":" + displayMinute + label;
        // console.log(formattedTime);
        // console.log(formattedDate);
        props.navProp.navigate("Trip Planner",{userProp: props.userProp, formattedDate: formattedDate, formattedTime: formattedTime, destinationTo: destinationTo, startLocation: startingLocation, latitude: latitudeProp, longitude: longitudeProp});
        //send formattedDate and formattedTime 
    }
    props.navProp.setOptions({ header: () => <Header navProp={props.navProp} pageTitle={props.userProp} />})

    return (
        // <ScrollView>
        <View style={{flex: 1, height: '100%'}}>
            <View style={{ marginTop: 12, backgroundColor: 'white', paddingVertical: 12, marginHorizontal: 16, borderRadius: 8 }}>
                <CalendarPicker
                    restrictMonthNavigation={true}
                    minDate={today}
                    maxDate={sixMonthsLater}
                    onDateChange={(selectedDate) => { setDate(selectedDate) }}
                    nextTitle={"Next    "}
                    previousTitle={"    Previous"}
                    nextTitleStyle={{ color: '#739fff'}}
                    previousTitleStyle={{ color: '#739fff'}}
                    selectedDayColor={'#5e7cff'}
                    selectedDayTextColor={'whitesmoke'}
                    dayLabelsWrapper={{borderTopWidth: 0, borderBottomWidth: 0, borderBottomColor: '#dee8ff'}}
                />
            </View>
            <View style={{marginVertical: 10, width: '100%', alignItems: 'center'}}>
                <View style={{width: '85%', display: 'flex', flexDirection: 'row', paddingVertical: 8}}>
                    <View style={{ flex: 1, justifyContent: 'space-evenly'}}>
                        <Text style={[Styles.GeneralText, { marginBottom: 0}]}>Please choose a time:</Text> 
                    </View>

                    <View style={{ flex: 1}}>
                        {Platform.OS == 'android' && (
                            <View style={{ alignItems: 'center', borderRadius: 6, flexDirection: 'row'}}>
                            <Text style={{borderTopLeftRadius: 6, borderBottomLeftRadius: 6, fontSize: 18, flex: 2, backgroundColor: 'white', paddingVertical: 4, paddingHorizontal: 4, height: '100%'}}>{displayTime}</Text>
                            <TouchableOpacity onPress={showTimePicker} style={{flex: 1}}>
                                <Text style={[Styles.editTimeButton, {borderTopLeftRadius: 0, borderBottomLeftRadius: 0, backgroundColor: '#739fff', color: 'whitesmoke', fontSize: 16}]}>Edit</Text>
                            </TouchableOpacity>
                        </View>
                        
                        )}

                        {Platform.OS == 'ios' && (
                            <View style={{width: '100%'}}>
                            <DateTimePicker
                            testID="time"
                            value={time}
                            mode='time'
                            is24Hour={true}
                            display="default"
                            confirmBtnText="Confirm"
                            cancelBtnText="Cancel"        
                            onChange={changeTime}
                            />
                            </View>
                        )}

                        <View style={{flex: 1}}>
                            {isTimePickerShow && (
                                <DateTimePicker
                                testID="time"
                                value={time}
                                mode='time'
                                is24Hour={true}
                                display="default"
                                confirmBtnText="Confirm"
                                cancelBtnText="Cancel"        
                                onChange={changeTime}
                                style={{
                                    width: 'auto',
                                    display: 'flex',
                                    alignItems: 'flex-start',    
                                }}
                                />
                            )}
                        </View> 
                    </View>
                </View>
            </View>




            <View style={{backgroundColor: 'white', borderTopLeftRadius: 24, borderTopRightRadius: 24, flex: 1, justifyContent: 'flex-end', paddingBottom: 40, alignItems: 'center'}}>
                <View style={{ flex: 1, justifyContent: 'flex-start', marginTop: 20, width: '85%'}}>
                    <View style={{ flex: 1, marginBottom: 16}}>
                        <Text style={{ fontSize: 20, fontWeight: '700'}}>Overview of Trip:</Text>
                    </View>
                    <View style={{ flex: 1, flexDirection: 'row'}}>
                        <Text style={{ flex: 1, fontSize: 16}}>Date:</Text>
                        <Text style={{ flex: 3, fontSize: 16, color: '#4c83fc'}}>{displayDate.toLocaleDateString()}</Text>
                    </View>
                    <View style={{flex: 1, flexDirection: 'row'}}>
                        <Text style={{ flex: 1, fontSize: 16}}>Time: </Text>
                        <Text style={{ flex: 3, fontSize: 16, color: '#4c83fc'}}>{displayTime}</Text>
                    </View>
                    <View style={{ flex: 1, flexDirection: 'row'}}>
                        <Text style={{ flex: 1, fontSize: 16}}>From:</Text>
                        <View style={{ flex: 3}}>
                            <ScrollView horizontal={true} showsHorizontalScrollIndicator={true} style={{flex: 1}}>
                                <Text style={{ fontSize: 16, color: '#4c83fc'}}>{startingLocation}</Text>
                            </ScrollView>
                        </View>
                    </View>
                    <View style={{ flex: 1, flexDirection: 'row'}}>
                        <Text style={{ flex: 1, fontSize: 16}}>To:</Text>
                        <View style={{ flex: 3}}>
                            <ScrollView horizontal={true} showsHorizontalScrollIndicator={true} style={{flex: 1}}>
                                <Text style={{ fontSize: 16, color: '#4c83fc'}}>{destinationTo}</Text>
                            </ScrollView>
                        </View>
                    </View>
                </View>
                <View style={{ width: '85%', flex: 1, justifyContent: 'flex-end'}}>
                    <View style={{ flex: 2}}>
                        <Text style={{ fontSize: 16, marginTop: 8, alignItems: 'flex-start'}}>If the above information is correct, click the button below to choose who will be driving you.</Text>
                    </View>
                    <View style={{alignItems: 'center', flex: 1}}>
                        <Pressable style={{
                            backgroundColor: '#739fff',
                            height: 'auto',
                            borderRadius: 10,
                            // marginTop: 80,
                            marginHorizontal: 12,
                            width: '100%',
                            paddingHorizontal: 20,
                            paddingVertical: 6,
                            alignItems: 'center',
                            justifyContent: 'center',
                        }} onPress={() => submitDateAndTime(date, hour, minute, label)}><Text style={[Styles.NextButtonText, { fontSize: 20}]}>Choose Driver</Text>
                        </Pressable>
                    </View>
                </View>
            </View>
        </View>
        // </ScrollView>
    );
}