// By Patrick Karangwa
// This page is intended to allow the passenger to search for a destination using
// Google Place Autocomplete feature.
import { Text, View, TouchableOpacity, TextInput, Alert,Platform, KeyboardAvoidingView} from 'react-native';
import React, {useState} from 'react';
import Styles from '../shared/styles/Styles';
import { GooglePlacesAutocomplete } from 'react-native-google-places-autocomplete';
import * as Location from 'expo-location';
import Header from '../components/Header';

export default class DestinationSelector extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            location: {},
            destination: '',
            startingAddress: '',
            latitudeState: '',
            longitudeState: '',
            startFromElsewhere: false
        };
    }

    
      componentDidMount() {
        this._getLocation();
        this.props.navProp.setOptions({ header: () => <Header navProp={this.props.navProp} pageTitle={this.props.userProp} />})
      }
    
      _getLocation = async () => {
        const { status } = await Location.requestForegroundPermissionsAsync();
        if(status != 'granted') { console.warn("Permission NOT granted..."); }
        const location = await Location.getCurrentPositionAsync();
        this.setState({ location })
      }
     
    verifyAddress() {
        console.log("Verify: " + this.state.destination);
        console.log("LatitudeState: " + this.state.latitudeState);
        console.log("LongState:" + this.state.longitudeState);
        if(this.state.startingAddress == '' || this.state.startingAddress == undefined){
            Alert.alert(" No starting location chosen.", "Please choose a starting location before moving on.");
            return;
        }
        else if(this.state.startFromElsewhere){
            if(this.state.startingAddress == '' || this.state.startingAddress == undefined) {
                Alert.alert(" No starting location chosen.", "Please choose a starting location before moving on.")
                return;
            }
        }
        if(this.state.latitudeState == undefined || this.state.longitudeState == undefined){
            // this.state.latitudeState = '44'; // for testing
            // this.state.longitudeState = '88'; // for testing
            Alert.alert( "Please wait a moment.", "We are currently getting your current location. Please try again in a few seconds. [DEVS: if needed, uncomment the two lines above this for testing]")
        }
        else if(this.state.destination == '' || this.state.destination == undefined){
            Alert.alert( "No destination chosen.", "Please choose a destination before moving on.");
        }
        else{
            this.props.navProp.navigate("Date Time Selector",{userProp: this.props.userProp, destinationTo: this.state.destination, startLocation: this.state.startingAddress, latitude: this.state.latitudeState, longitude: this.state.longitudeState});
        }
    }

    render(){
    // let latitude = this.props.latitudeProp;
    // let longitude = this.props.longitudeProp;
    let json = JSON.stringify(this.state.location);
    let json_parsed = JSON.parse(json);
    let coords_json = json_parsed["coords"] || "{}";
    let latitude = coords_json["latitude"];
    let longitude = coords_json["longitude"];
    this.state.latitudeState = latitude;
    this.state.longitudeState = longitude;
    let destinationTo = '';
    let destinationStartingAddress = '';

    const GOOGLE_PLACES_API_KEY = 'API_KEY_HERE';
    return (
    <KeyboardAvoidingView behavior={Platform.OS === "ios" ? "padding" : "height"} style={{flex: 1}}>
        <View style={[Styles.container]}>
            <View style={{width: '100%', alignItems: 'center'}}>
                <Text style={{ marginVertical: 4, width: '85%', textAlign: 'center', fontSize: 16, fontWeight: '500'}}>In the box below, enter your destination. Select from the dropdown menu.</Text>
            </View>


            <GooglePlacesAutocomplete
                placeholder='Where do you need to go?'
                query={{
                    key: GOOGLE_PLACES_API_KEY,
                    language: 'en',
                }}
                onPress={(data, details = null) => {
                    // 'details' is provided when fetchDetails = true
                    destinationTo = JSON.parse(JSON.stringify(data))["description"];
                    this.state.destination = destinationTo;
                    console.log("Address: " + destinationTo);
                }}
            /> 
            {this.state.startFromElsewhere && (
                <GooglePlacesAutocomplete
                    placeholder='Where are you starting from?'
                    query={{
                        key: GOOGLE_PLACES_API_KEY,
                        language: 'en',
                    }}
                    onPress={(data, details = null) => {
                        destinationStartingAddress = JSON.parse(JSON.stringify(data))["description"];
                        this.state.startingAddress = destinationStartingAddress;
                        console.log("Starting Address: " + destinationStartingAddress);
                    }}
                /> 
            )}

            <View style={{justifyContent: 'center', alignContent: 'center', alignItems: 'center'}}>
                <View style={{flexDirection: 'row', width: '85%'}}>
                    <View style={{flex: 1, backgroundColor: '#25c29d', marginHorizontal: 2, paddingVertical: 4, borderRadius: 8}}>
                        <TouchableOpacity style={{alignItems: 'center'}} onPress={() => this.setState({ startFromElsewhere: false, startingAddress: "Current Location"})}>
                            <Text style={{fontSize: 16, color: 'white', textAlign: 'center'}}>Start from Current Location</Text>
                        </TouchableOpacity>
                    </View>
                    <View style={{flex: 1, backgroundColor: '#3d8eff', marginHorizontal: 2, paddingVertical: 4, borderRadius: 8}}>
                        <TouchableOpacity style={{alignItems: 'center'}} onPress={() => this.setState({ startFromElsewhere: true}) }> 
                            <Text style={{fontSize: 16, color: 'white', textAlign: 'center'}}>Start from somewhere else</Text>
                        </TouchableOpacity>
                    </View>
                </View>
            </View>

            <View style={[Styles.NextButtonContainer, {width:'100%', justifyContent: 'center', bottom: 0}]}>
                <View style={{ width: '100%', left: 0, alignItems: 'center'}}>
                <TouchableOpacity
                    style={[Styles.NextButtonPressable, { width: '85%'}]}
                    onPress={() => this.verifyAddress()}>
                        <Text style={[Styles.NextButtonText, { fontSize: 16, }]}>Choose Date & Time</Text>
                </TouchableOpacity>
                </View>
                <View style={{marginBottom: 24}}></View>

            </View>

            {/* </View> */}
        </View>
    </KeyboardAvoidingView>
    );
    }
}