import { Text, View, TouchableOpacity, StatusBar, Modal, Keyboard, ScrollView, Linking, FlatList, Alert} from 'react-native';
import { React, useState, useEffect } from 'react';
import Styles from '../shared/styles/Styles';
import Divider from 'react-native-divider';
import HeaderDriver from '../components/HeaderDriver';
import * as Device from 'expo-device';
import * as Notifications from 'expo-notifications';

// FlatList: renderItem: AcceptedItem
const AcceptedItem = ({ item, onPress }) => {
    return (
        <TouchableOpacity style={[Styles.driverHomeBtn, {backgroundColor: '#5e7eff', marginBottom: 4, height:'auto', marginTop: 12}]} onPress={onPress} >
            <View style={{ flex: 1, borderRightWidth: 1, borderRightColor: 'whitesmoke', flexDirection: 'column'}}>
                <View style={{flex: 1, marginBottom: 20}}>
                    <Text style={{color: 'white', fontSize: 16, fontWeight: '600'}}>{item.date.trim()}</Text>
                </View>
                <View style={{flex: 1}}>
                    <Text style={{fontSize: 20, fontWeight: '700', color: 'white'}}>{item.time.trim()}</Text>
                </View>
            </View>
            <View style={{ flex: 2, marginLeft: 12}}>
                <View style={{ flex: 1, flexDirection: 'column'}}>
                    <Text style={{ flex: 1, fontSize: 16, marginBottom: 8, fontWeight: '600', color: 'white'}}>{item.first_name.trim()} {item.last_name.trim()}</Text>
                    <View style={{flex: 1, justifyContent: 'flex-end' }}>
                        <Text style={{ fontSize: 16, color: 'white'}}>({item.phone.trim()[0]}{item.phone.trim()[1]}{item.phone.trim()[2]}) {item.phone.trim()[3]}{item.phone.trim()[4]}{item.phone.trim()[5]}-{item.phone.trim()[6]}{item.phone.trim()[7]}{item.phone.trim()[8]}{item.phone.trim()[9]}</Text>
                    </View>
                </View>
            </View>
        </TouchableOpacity>
    )
};

export default function DriverHome(props) {
    let driverPhoneNumber = props.userProp; 

    const [modalVisible, setModalVisible] = useState(false);
    const [selectedPhoneNumber, setSelectedPhoneNumber] = useState("0");
    const [atleastOneTodayRequest, setAtleastOneTodayRequest] = useState(false);
    const [atleastOneFutureRequest, setAtleastOneFutureRequest] = useState(false) ;

    // FlatList: data
    const [acceptedRequests, addAcceptedRequests] = useState([]);
    const [futureAcceptedRequests, addFutureAcceptedRequests] = useState([]);

    // request permission to access notifications. (Is this needed? Maybe they already have permission from home page.)
    registerForPushNotificationsAsync = async() => {
        // check for existing permissions
        const {status: existingStatus} = await Notifications.getPermissionsAsync();
        let finalStatus = existingStatus;
    
        //If there are no existing permissions
        if (existingStatus !== 'granted'){
            const {status} = await Notifications.requestPermissionsAsync();
            finalStatus = existingStatus;
        }
    
        //If the permission is still not granted, exit the funciton
        if (finalStatus !== 'granted')
        {
            alert('Failed to get token for push notifications.');
            return;
        }
    }

    // useEffect to grab list of accepted requests given a phone number
    useEffect(() => {
        var todaysRequests = [];
        var futureRequests = [];

        var driverNumber = {
            "driver_phone": driverPhoneNumber
        }
        let specifications = {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json;charset=utf-8'
            },
            body: JSON.stringify(driverNumber)
        }
        fetch("https://magicdjangoapp.herokuapp.com/transportation/transportation_list/", specifications)
            .then(response => response.json())
            .then(jsonResponse => {
                var today = new Date();
                var dd = String(today.getDate()).padStart(2, '0');
                var mm = String(today.getMonth() + 1).padStart(2, '0');
                var yy = today.getFullYear().toString();
                today = mm + '/' + dd + '/' + yy[2]+yy[3];
                // console.log(today); // for testing
                // today = "05/01/22"; // for testing
                jsonResponse.forEach(element => {
                    if(element["date"].trim() == today){
                        todaysRequests.push(element);
                        setAtleastOneTodayRequest(true);
                    }
                    else{
                        futureRequests.push(element);
                        setAtleastOneFutureRequest(true);
                    }
                });
                addAcceptedRequests(todaysRequests);
                addFutureAcceptedRequests(futureRequests);
            })
            .catch(error => console.log(error))
    }, []);
    
    // FlatList: renderItem
    const renderItem = ({ item, todayOrFuture }) => {
        return (
            <AcceptedItem 
                item={item}
                onPress={() => {setModalVisible(!modalVisible), setSelectedPhoneNumber(item.phone)}}
            />
        );
    }

    const makeCall = (number) => {
        let phoneNumber = '';
        if (Platform.OS == 'android'){
            phoneNumber = 'tel:${'+number+'}';
        }
        else{
            phoneNumber = 'telprompt:${'+number+'}';
        }
        Linking.openURL(phoneNumber);
    }

    const checkIn = (phoneNumber) => {
        // grab passenger's token using phone number
        let specifications = {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json;charset=utf-8'
            },
            body: JSON.stringify({"user": phoneNumber })
        };
        fetch('https://magicdjangoapp.herokuapp.com/pushtokens/push_token/', specifications)
        .then(response => response.json())
        .then(jsonResponse => {
            // send notification with contents to expo-server-sdk
            const message = {
                to: jsonResponse[0].token[0].trim(),
                sound: 'default',
                title: 'Your driver is here!',
                body: 'Your driver has checked in at the pick-up location you requested.',
                data: { phone: driverPhoneNumber, notificationType: "checkin" },
            };
            fetch('https://exp.host/--/api/v2/push/send', {
                method: 'POST',
                headers: {
                    Accept: 'application/json',
                    'Accept-encoding': 'gzip, deflate',
                    'Content-Type': 'application/json'
                },
                body: JSON.stringify(message),
            })
            .catch(error => console.log("Check In Send Error 1: "+error));
        })
        .catch(error => console.log("Check In Send Error 2: "+error));
        // Alert driver that the check in notification has been sent
        Alert.alert("Sent!", "The passenger has been notified that you are at the pick up location.");
    }

    props.navProp.setOptions({ header: () => <HeaderDriver navProp={props.navProp} pageTitle={props.userProp} />})

    return (
    <ScrollView style={Styles.container} nestedScrollEnabled={true}>
        <View style={{width: '100%'}}>
            <View style={{ position: 'relative', alignItems: 'center', justifyContent: 'center', alignContent: 'center',}}>
                <StatusBar
                    backgroundColor="#F2F2F7"
                    barStyle='dark-content'>
                </StatusBar>

                <Modal
                    animationType="fade"
                    transparent={true}
                    visible={modalVisible}
                    onRequestClose={() => {
                        setModalVisible(!modalVisible);
                    }}
                    >
                    <TouchableOpacity style={{ flex: 1, justifyContent: "flex-end", alignItems: "center", backgroundColor: '#000000aa'}} activeOpacity={1} onPress={() => {Keyboard.dismiss()}}>
                        <View style={{ flex: 0.20, backgroundColor: "white", borderTopLeftRadius: 24, borderTopRightRadius: 24, width: '100%', padding: 28, alignItems: "center", shadowColor: "#000", shadowOffset: { width: 0, height: 2 }, shadowOpacity: 0.25, shadowRadius: 24, elevation: 5, justifyContent: 'flex-start'}}>
                        <View>
                            <Text style={{ fontSize: 17, marginBottom: 15, textAlign: "center" }}>If you have arrived at the requested location, please check in below:</Text>
                        </View>
                        <View style={{flexDirection: 'row'}}>
                            <TouchableOpacity style={[{ flex: 1, margin: 4, borderRadius: 8, padding: 10, backgroundColor: "#25c29d" }]} onPress={() => {setModalVisible(!modalVisible), checkIn(selectedPhoneNumber)}} >
                                <Text style={{ fontSize: 16, color: "white", fontWeight: "bold", textAlign: "center" }}>Check In</Text>
                            </TouchableOpacity>
                            <TouchableOpacity style={[{ flex: 1, margin: 4, borderRadius: 8, padding: 10, backgroundColor: "#6b9aff" }]} onPress={() => {setModalVisible(!modalVisible), makeCall(selectedPhoneNumber)}}>
                                <Text style={{ fontSize: 16, color: "white", fontWeight: "bold", textAlign: "center" }}>Call</Text>
                            </TouchableOpacity>
                            <TouchableOpacity style={[{ flex: 1, margin: 4, borderRadius: 8, padding: 10, backgroundColor: "grey" }]} onPress={() => setModalVisible(!modalVisible)} >
                                <Text style={{ fontSize: 16, color: "white", fontWeight: "bold", textAlign: "center" }}>Cancel</Text>
                            </TouchableOpacity>
                        </View>
                        
                        </View>
                    </TouchableOpacity>
                </Modal>


                <View style={{ width: '88%', marginTop: 44, marginBottom: 220 }}>
                    <Text style={[Styles.GeneralHeaderText, { marginBottom: 8}]}>Accepted Ride Requests</Text>
                    <View style={{borderRadius: 8, paddingVertical: 16, marginBottom: 20}}>
                        <Text style={{fontSize: 16, lineHeight: 24}}>Once you have arrived at the requested pick-up location, click on that Ride to check-in or call the passenger. </Text> 
                        <Text style={{fontSize: 16, marginTop: 12, lineHeight: 24}}>Checking in will send a notification to the passenger to let them know you have arrived.</Text>
                        <Text style={{fontSize: 16, marginTop: 12, lineHeight: 24}}>These accepted requests should also be included in your calendar. You can check there for the same information.</Text>
                    </View>
                    <Divider borderColor="#466682" color="#466682" orientation="center">Today's Rides</Divider>
                    {!atleastOneTodayRequest && (
                        <View style={{width: '100%'}}>
                            <Text style={{color: '#466682', textAlign: 'center', marginVertical: 12}}>No schedule rides for today!</Text>
                        </View>
                    )}
                    <ScrollView horizontal={true} style={{ width: "100%", flexDirection: 'column'}}>
                        <FlatList
                            scrollEnabled={false}
                            data={acceptedRequests}
                            renderItem={renderItem}
                            keyExtractor={(item, index) => {return item.phone;}}
                            />
                    </ScrollView>

                    <View style={{marginTop: 12}}></View>
                    <Divider borderColor="#466682" color="#466682" orientation="center">Future Rides</Divider>
                    {!atleastOneFutureRequest && (
                        <View style={{width: '100%'}}>
                            <Text style={{color: '#466682', textAlign: 'center', marginVertical: 12}}>No future scheduled rides!</Text>
                        </View>
                    )}
                    <ScrollView horizontal={true} style={{ width: "100%", flexDirection: 'column'}}>
                        <FlatList
                            scrollEnabled={false}
                            data={futureAcceptedRequests}
                            renderItem={renderItem}
                            keyExtractor={(item, index) => {return item.phone;}}
                            />
                    </ScrollView>
                </View>
            </View>
        </View>
    </ScrollView>
    );
}