import { Text, View, Image, TouchableOpacity, StatusBar, Modal, TextInput, FlatList, TouchableWithoutFeedback, Keyboard, Platform, Alert, ScrollView } from 'react-native';
import { React, useState, useEffect, useRef } from 'react';
import Styles from '../shared/styles/Styles';
import HelpModal from '../components/HelpModal';
//import SendRequest from '../components/SendRequest/SendRequest';
import * as Device from 'expo-device';
import * as Notifications from 'expo-notifications';
import HeaderDriver from '../components/HeaderDriver';
import { UIImagePickerPresentationStyle } from 'expo-image-picker';
import * as Location from 'expo-location';
//import getDirections from 'react-native-google-maps-directions';
//import {Expo} from 'expo-server-sdk';
//import sendPushNotification from '../components/PushNotifications';
//import PushNotifications from '../components/PushNotifications';

export default function DriverHome(props) {
  let driverPhoneNumber = props.userProp;

  const [availableNow, setAvailableNow] = useState(false);
  const [showFriendRequest, setShowFriendRequest] = useState(false);
  const [allPassengers, setAllPassengers] = useState([]);
  const [filteredPassengers, setFilteredPassengers] = useState([]);
  const [passengersLoaded, setPassengersLoaded] = useState(false);
  const [passengerSelected, setPassengerSelected] = useState(false);
  const [selectedId, setSelectedId] = useState(null);
  const [selectedName, setSelectedName] = useState('');
  const [placeholderText, setPlaceholderText] = useState('Enter name or phone number');
  const [searchParam, setSearchParam] = useState('');
  const [notification, setNotification] = useState({});
  const [currentLocation, setCurrentLocation] = useState({});

  let firstName = '';
  let lastName = '';
  let name = '';
  let id = 0;

  //Requesting permission to access notifications
  registerForPushNotificationsAsync = async() => {
    //Check for existing persmisions
    const {status: existingStatus} = await Notifications.getPermissionsAsync();
    let finalStatus = existingStatus;

    //If there are no existing permissions
    if (existingStatus !== 'granted'){
        const {status} = await Notifications.requestPermissionsAsync();
        finalStatus = existingStatus;
    }

    //If the permission is still not granted, exit the funciton
    if (finalStatus !== 'granted')
    {
        alert('Failed to get token for push notifications.');
        return;
    }
  };

  //Handler to determine how notifications are handled when the app
  //is in the foreground.
  Notifications.setNotificationHandler({
    handleNotification: async () => ({
      shouldShowAlert: true,
      shouldPlaySound: false,
      shouldSetBadge: false,
    }),
  });

  useEffect(() => {
    _getLocation();
    registerForPushNotificationsAsync();
    Notifications.addNotificationReceivedListener(_handleNotification);
    Notifications.addNotificationResponseReceivedListener(_handleNotificationResponse);
  }, []);

  //Get current location
  _getLocation = async () => {
    const { status } = await Location.requestForegroundPermissionsAsync();
    if(status != 'granted') { console.warn("Permission NOT granted..."); }
    const location = await Location.getCurrentPositionAsync();
    setCurrentLocation(location);
    //let json = JSON.stringify(currentLocation)
    //console.log("Driver Location: " + json);
  };

  //Getting the lat-long values for the driver
  useEffect(() => {
    let json = JSON.stringify(currentLocation);
    let json_parsed = JSON.parse(json);
    let coords_json = json_parsed["coords"] || "{}";
    let driverLatitude = coords_json["latitude"];
    let driverLongitude = coords_json["longitude"];
    console.log("Driver lat: " + driverLatitude);
    console.log("Driver long: " + driverLongitude);

  }, [])

  //Received notification listener
    _handleNotification = notification => {
        setNotification(notification);//HERE
  };

  //Notification response listener
  _handleNotificationResponse = response => {
    //Fetch information about the passenger who sent the request
    let passengerPhone = response.notification.request.content.data.phone;
    let pickupLat = response.notification.request.content.data.pickupLat;
    let pickupLong = response.notification.request.content.data.pickupLong;
    let destinationLat = '';
    let destinationLong = '';

    //Initialize data for requesting directions
    /*const data = {
      source: {
       latitude: driverLatitude,
       longitude: driverLongitude
     },
     destination: {
       latitude: pickupLat,
       longitude: pickupLong
     },
     params: [
       {
         key: "travelmode",
         value: "driving"        // may be "walking", "bicycling" or "transit" as well
       },
       {
         key: "dir_action",
         value: "navigate"       // this instantly initializes navigation using the given travel mode
       }
     ],
    };*/

    //console.log("Passenger phone: " +passengerPhone);
    let firstName = '';
    let lastName = '';
    let id = 0;
    let Name = '';
    let specifications = {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json;charset=utf-8'
      },
      body: JSON.stringify({'user' : passengerPhone})
    };
    fetch("https://magicdjangoapp.herokuapp.com/passengers/find_passenger/", specifications)
    .then(resp => resp.json())
    .then(jsonResponse => {
      let passengerInfo = {};
      Object.entries(jsonResponse).forEach(([key, value]) => {
        if (key === 'first_name'){
          firstName = value;
          firstName = firstName.trim();
        }
        if (key === 'last_name'){
            lastName = value;
            lastName = lastName.trim();
        }
        if (key === 'phone'){
            id = value;
        }
        Name = firstName + ' ' + lastName;
        passengerInfo = {Name, id};
      })
      Alert.alert(
        passengerInfo.Name + " has requested a ride",
        "Phone number: " + passengerInfo.id,
        [
          {
            text: "Accept",
            onPress: () => {
              //getDirections(data);
                console.log("sync to calendar when start and end locations are sent from trip planning");
            }
          },
          {
            text: "Decline",
            onPress: () => {}
          }
        ]
      )
      
    })
  }

  const PassengerListItem = ({ item, onPress, backgroundColor, textColor }) => {
    return (
    <TouchableOpacity 
        onPress={onPress} 
        style={[Styles.friendSelectionListItem,backgroundColor]}>
          <View style={Styles.friendLookupContainer}>
            <View style={Styles.friendSelectionImageContainer}>
              <Image style={[Styles.accountIcon]} source={require('../assets/account.png')} />
            </View>
            <View style={Styles.friendSelectionInfoContainer}>
              <Text style={[Styles.driverListTitle, textColor]}>{item.name}</Text>
              <Text style={[Styles.driverListTitle, textColor]}>{formatPhoneNumber(item.id)}</Text>             
            </View>
          </View>
  
    </TouchableOpacity>
    )
  };

  //useEffect to fetch all of the passengers for filtering or searching through.
  useEffect(() => {
    let specifications = {
        method: 'GET',
        headers: {
            'Content-Type': 'application/json;charset=utf-8'
        }
    }
    fetch("https://magicdjangoapp.herokuapp.com/passengers", specifications)
        .then(response => response.json())
        .then(jsonResponse => {
            jsonResponse.forEach(object => {
                Object.entries(object).forEach(([key, value]) => {
                    if(key === 'first_name'){
                        firstName = value;
                        firstName = firstName.trim();
                    }
                    if(key === 'last_name'){
                        lastName = value;
                        lastName = lastName.trim();
                    }
                    if(key === 'phone'){
                        id = value;
                    }
                    name = firstName + ' ' + lastName;
                    currentPassenger = {name, id};

                    setAllPassengers((prevPassengers) => {//HERE
                        return [...prevPassengers.filter(passenger => passenger.id != id), currentPassenger ]
                    });
                    setFilteredPassengers((prevPassengers) => {//HERE
                      return [...prevPassengers.filter(passenger => passenger.id != id), currentPassenger ]
                    });
                });
            });
            setPassengersLoaded(true);//HERE
        })
        .catch(error => console.log("Call 1 error: " + error));
  }, []);

  /*useEffect(() => {
    console.log('all passengers: ' + allPassengers);
    console.log('filtered passengers: ' + filteredPassengers);
  }, [passengersLoaded])*/

  useEffect(() => {
    //console.log(searchParam);
    filterUsers(searchParam);
  }, [searchParam]);

  const submitRequest = (passengerSelected) => {
    if(passengerSelected){
      //console.log("Friend request sent to: " + filteredPassengers.filter(passenger => passenger.id === selectedId));
      setShowFriendRequest(false);
      setPassengersLoaded(false);
      setSelectedId(0);
      setPassengerSelected(false);
      filterUsers('');
      
      //POST request to obtain the passenger's token
        let specifications = {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json;charset=utf-8'
            },
            body: JSON.stringify({ "user": selectedId })
        };
      fetch('https://magicdjangoapp.herokuapp.com/pushtokens/push_token/', specifications)
      .then(response => response.json())
      .then(jsonResponse => {
          //Sending notification with contents to the expo-server-sdk
          const message = {
              to: jsonResponse[0].token[0].trim(),
              sound: 'default',
              title: 'New Friend Reqest',
              body: 'A driver has requested to be added to the friends list',
              data: { phone: driverPhoneNumber, notificationType: "friendrequest" },
          };
          fetch('https://exp.host/--/api/v2/push/send', {
              method: 'POST',
              headers: {
                  Accept: 'application/json',
                  'Accept-encoding': 'gzip, deflate',
                  'Content-Type': 'application/json',
              },
              body: JSON.stringify(message),
          })
              .catch(error => console.log("Call 3 error: " + error));
      })
            .catch(error => console.log("Call 2 error: " + error)); 
      //Alert the the user that the request has been sent
      alert("Request sent to: " + selectedName);   
    }
    else{
      return alert('Please select a passenger to send request to...');
    }

  }

  const onFocus = () => {
    setPlaceholderText('');
  }

  const onBlur = () => {
    setPlaceholderText('Enter name or phone number')
  }

  const formatPhoneNumber = (phoneNumber) => {
    let newNumber = '';
    let formattedNumber = ('' + phoneNumber).replace(/\D/g, '');
    for( var i = 0; i < formattedNumber.length; i++){
      if(i == 0){
        newNumber = '(';
      } 
      else if(i == 3){
        newNumber = newNumber + ') ';
      }
      else if(i == 6){
        newNumber = newNumber + '-';
      }
      newNumber = newNumber + formattedNumber[i];
    }
    return (newNumber);
  }

  const filterUsers = (textToSearch) => {
    if(textToSearch.length > 0){
      setFilteredPassengers(() => {
        if(isNaN(textToSearch)){
          return allPassengers.filter(passenger => passenger.name.toLowerCase().includes(textToSearch));
        }
        else
          return allPassengers.filter(passenger => passenger.id.includes(textToSearch));
        });
    } 
    else{
      setFilteredPassengers(() => {
        return allPassengers;
      });
    }
  }

  const renderItem = ({ item }) => {
    const backgroundColor = item.id === selectedId ? '#4484eb' : '#bfd3ff';
    const color = item.id === selectedId ? '#FFFFFF' : '#000000';
    return (
        <PassengerListItem 
            item={item}
            onPress={() => {
              if(passengerSelected === true){
                setSelectedId(0);
                setSelectedName('');
                setPassengerSelected(!passengerSelected);
                setSearchParam('');
              }
              else{
                setSelectedId(item.id);
                setSelectedName(item.name);
                setPassengerSelected(!passengerSelected);
                setSearchParam(item.id);
              }

              }
            }
            backgroundColor={{ backgroundColor }}
            textColor={{ color }}
        />
    );
  }

  // grab immediate availability value from database and set availableNow equal to that
  useEffect(() => {
    // grab real Driver's phone number here?
    var phoneNumberImmediate = {
      "phone": driverPhoneNumber, // temporary phone number for now
      "email_address": "",
      "date": "",
      "start_time": "",
      "end_time": ""  
    };

    let specifications = {
      method: 'POST',
      headers: {
          'Content-Type': 'application/json;charset=utf-8'
      },
      body: JSON.stringify(phoneNumberImmediate)
    }
    // call to grab immediate availabilty boolean value
    // set availableNow value to value in database
    fetch("https://magicdjangoapp.herokuapp.com/driverschedule/get_immediate_availability/", specifications)
    .then(response => response.json())
    .then(jsonResponse => {
      //console.log("Current DB value: "+jsonResponse);
      if(jsonResponse == "True")
        setAvailableNow(true);
      else
        setAvailableNow(false);
    }).catch(error => console.log("Call 4 error: " + error));

  }, []);

  // updates immediate availability of driver
  function updateImmediateAvailability() {

    // grab real Driver's phone number here?
    var phoneNumberImmediate = {
      "phone": driverPhoneNumber, // temporary phone number for now
      "email_address": "",
      "date": "",
      "start_time": "",
      "end_time": ""  
    };

    let specifications = {
      method: 'POST',
      headers: {
          'Content-Type': 'application/json;charset=utf-8'
      },
      body: JSON.stringify(phoneNumberImmediate)
    }
    fetch("https://magicdjangoapp.herokuapp.com/driverschedule/set_immediate_availability/", specifications)
    .then(response => response.json())
    .then(jsonResponse => {
      console.log(jsonResponse);
    })
    .catch(error => console.log("Call 5 error: " + error));

    // a problem could be if multiple testers are using the same phone number and editing the database at the same time for the same phone number?
    // another problem is if the user sets themselves as 'Available to Drive', quits the app, then comes back. The database still holds a 'true' value, 
    // so they should still see green text telling them they're currently available to passengers...

    // possible solution: check value at beginning of session to update 'availableNow' value so it matches the value in the database instead of defaulting to 'false' every new session. (implemented using useEffect() above)
    // possible solution 2: if user exits session, update their immediate availability to 'false' (not implemented)
  }  

  // popup alert for user to adjust immediate availability
  function availableToDrive() {
    if(availableNow){
      Alert.alert(
        "Set yourself as currently 'Unavailable'?",
        "",
        [
          { text: "Nevermind" },
          { text: "Yes", onPress: () => {
              Alert.alert( "Current availability turned off.", "However, if you are still scheduled to drive right now, you will be seen as available to passengers."), 
              updateImmediateAvailability();
              setAvailableNow(false); // should this be moved inside the successful update API call?
            }
          }
        ]  
      );
    }
    else{
      updateImmediateAvailability();
      setAvailableNow(true); // should this be moved inside the successful update API call?
      Alert.alert("You are now currently available to passengers!","You will be seen as available regardless of your current schedule. Click again to turn off.");
    }
  }

  //console.log("Driver Home: Phone:"+props.userProp);
    useEffect(() => { props.navProp.setOptions({ header: () => <HeaderDriver navProp={props.navProp} pageTitle={props.userProp} /> });})

  return (
    <View style={[Styles.container, {marginTop: 80}]}>
      <ScrollView>
        <View style={Styles.driverHomeBtnContainer}>
        <StatusBar
          backgroundColor='#F2F2F7'
          barStyle='dark-content'>
        </StatusBar>
          <View>
            <Modal visible={showFriendRequest} transparent={true} animationType="slide">
              <TouchableWithoutFeedback onPress={Keyboard.dismiss}>
                <View style={{backgroundColor: "#000000aa", flex:1, justifyContent: 'center'}}>
                  <View style={Styles.friendRequestModalView}>
                    <View style={{flex: 1}}>
                      <Text style={Styles.friendRequestModalTitle}>Send Friend Request</Text>
                      <TextInput 
                        onFocus={() => onFocus()}
                        onBlur={() => onBlur()}
                        onChangeText={(text) => {
                          if(isNaN(text)){
                            setSearchParam(text.toLowerCase());
                          }
                          else if(!isNaN(text)){
                            setSearchParam(text);
                          }
                          else
                            setSearchName('');
                        }}
                        placeholder={placeholderText}
                        placeholderTextColor='#5D5D5D' 
                        style={Styles.friendRequestTextInput}>
                      </TextInput>
                    </View>
                    <View style={Styles.friendRequestPassengerView}>
                      <FlatList 
                        contentContainerStyle={{width: '100%'}}
                        data={filteredPassengers}
                        renderItem={renderItem}
                        keyExtractor={(item) => item.id}
                        extraData={passengerSelected}
                      />            
                    </View>

                    <View style={{ flex: 1, flexDirection: 'column', width: '100%', justifyContent: 'center'}}>
                      <View style={{width: '100%', alignItems: 'center'}}>
                        <TouchableOpacity 
                          style={{...Styles.submitFriendRequestBtn, alignContent: 'center', width: '100%', position: 'relative', bottom: 0}} 
                          onPress={()=> {
                              submitRequest(passengerSelected);
                              //alert("Friend Request successfully sent to ")
                            }
                          }>
                          <Text style={{color: 'whitesmoke', fontWeight: 'bold', fontSize: 20, textAlign: 'center',}}>Send Request</Text>
                          {/* <MaterialIcons name="send" size={20} style={Styles.submitIcon} /> */}
                        </TouchableOpacity>
                      </View>  

                      <View style={{width: '100%', alignItems: 'center'}}>
                        <TouchableOpacity 
                          style={{...Styles.submitFriendRequestBtn, backgroundColor: 'grey', alignContent: 'center', width: '100%', position: 'relative', bottom: 0}} 
                          onPress={()=> {
                              setShowFriendRequest(false);
                            }
                          }>
                          <Text style={{ color: 'whitesmoke', fontWeight: 'bold', fontSize: 20, textAlign: 'center',}}>Close</Text>
                          {/* <MaterialIcons name="close" size={20} style={Styles.submitIcon} /> */}
                        </TouchableOpacity>
                      </View>
                    </View>

                  </View>

                </View>
              </TouchableWithoutFeedback>  
            </Modal>
          </View>

          <View style={{ width: '85%', alignContent: 'center' }}>
            <Text style={Styles.GeneralHeaderText}>Hello! </Text>
            {!availableNow && (
              <Text style={Styles.LargeGeneralText}>Where are we driving today?</Text>
            )}

            {availableNow && (
              <Text style={[Styles.LargeGeneralText, { color: 'green'}]}>You're currently available to passengers!</Text>
            )}

            <View>
              <TouchableOpacity style={[Styles.driverHomeBtn, Styles.passengerHomeBtn1]} onPress={() => availableToDrive()}>
                <Text style={Styles.buttonText}>Available to Drive</Text>
                <Image style={Styles.driverHomeIcon} source={require('../assets/check-box-2.png')}></Image>
              </TouchableOpacity>
            </View>

            <View>
              <TouchableOpacity style={[Styles.driverHomeBtn, Styles.passengerHomeBtn2]} onPress={() => props.navProp.navigate("Driver Schedule Availability", { userProp: driverPhoneNumber})} >
                <Text style={Styles.buttonText}>Set Availability</Text>
                <Image style={Styles.driverHomeIcon} source={require('../assets/calendar.png')}></Image>
              </TouchableOpacity>
            </View>

            <View>
              <TouchableOpacity style={[Styles.driverHomeBtn, Styles.passengerHomeBtn3]} onPress={() => setShowFriendRequest(true)} >
                <Text style={Styles.buttonText}>Send Friend Request</Text>
                <Image style={Styles.driverHomeIcon} source={require('../assets/friend-request.png')}></Image>
              </TouchableOpacity>
            </View>

            <View style={{ marginBottom: 60 }}></View>

            <View style={Styles.helpBtnWrapper}>
                <HelpModal />
            </View>
          </View>

        </View>
        <View style={{ marginBottom: 30 }}></View>
      </ScrollView>
    </View>
  );
} 

// export default DriverHome;


