// Author: Alan Torres
// This page currently is only useable by passengers.
// This takes the passengers phone number and grabs the list of all their driver friends.
//
// TODO: pass in phone prop

import { Text, View, TouchableOpacity, StatusBar, ScrollView, FlatList, Alert} from 'react-native';
import { React, useState, useEffect } from 'react';
import Styles from '../shared/styles/Styles';
import { Ionicons } from '@expo/vector-icons'; 
import Divider from 'react-native-divider';

// FlatList: renderItem: FriendItem
const deleteFriendship = (passenger_number, driver_number) => {
    var numbers = {
        "passenger_phone": passenger_number,
        "driver_phone": driver_number
    }
    let specifications = {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json;charset=utf-8'
        },
        body: JSON.stringify(numbers)
    }
    fetch("https://magicdjangoapp.herokuapp.com/friends/delete_friend/", specifications)
    .then(response => response.json())
    .then(jsonResponse => {
        console.log(jsonResponse);
        Alert.alert("Deleted", "The deletion was a success. Once you refresh the page, this friend will no longer be shown.");
    })
    .catch(error => console.log(error))
}

const FriendItem = ({ item, passenger_phone_number }) => {
    return (
        <View style={[Styles.driverHomeBtn, {backgroundColor: 'white', marginBottom: 4, height:'auto', marginTop: 12, borderWidth: 0.25, borderColor: 'grey', borderRadius: 8}]}>
            <View style={{ flex: 2, borderRightWidth: 0.25, borderRightColor: 'grey', flexDirection: 'column'}}>
                <Text style={{ fontSize: 16, color: 'black'}}>{item.first_name.trim()} {item.last_name.trim()}</Text>
            </View>
            <View style={{ flex: 2, marginLeft: 12}}>
                <Text style={{ fontSize: 16, color: 'black'}}>({item.phone.trim()[0]}{item.phone.trim()[1]}{item.phone.trim()[2]}) {item.phone.trim()[3]}{item.phone.trim()[4]}{item.phone.trim()[5]}-{item.phone.trim()[6]}{item.phone.trim()[7]}{item.phone.trim()[8]}{item.phone.trim()[9]}</Text>
            </View>
            <TouchableOpacity style={{flex: 0.5, backgroundColor: '#e34640', justifyContent: 'center', borderRadius: 4, alignItems: 'center', paddingVertical: 4}} onPress={() => deleteFriendship(passenger_phone_number, item.phone)}>
                <Ionicons name="md-trash-outline" size={20} color="white" />
            </TouchableOpacity>
        </View>
    )
};

export default function FriendList(props) {
    let passengerPhoneNumber = props.userProp;

    // array of friends
    const [friends, addFriends] = useState([]);

    const [deleteFriend, setDeleteFriend] = useState("0");

    // useEffect to grab list of friends given a phone number
    useEffect(() => {
        var passengerNumber = {
            "passenger_phone": passengerPhoneNumber
        }
        let specifications = {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json;charset=utf-8'
            },
            body: JSON.stringify(passengerNumber)
        }
        fetch("https://magicdjangoapp.herokuapp.com/friends/friends_list/", specifications)
            .then(response => response.json())
            .then(jsonResponse => {
                addFriends(jsonResponse);
            })
            .catch(error => console.log(error))
    }, []);

    // FlatList: renderItem
    const renderItem = ({ item }) => {
        return (
            <FriendItem 
                item={item}
                // onPress={() => setDeleteFriend(item.phone)}
                passenger_phone_number={passengerPhoneNumber}
                
            />
        );
    }



    return (
        <ScrollView style={Styles.container} nestedScrollEnabled={true}>
            <View style={{width: '100%'}}>
                <View style={{ position: 'relative', alignItems: 'center', justifyContent: 'center', alignContent: 'center',}}>
                    <StatusBar
                        backgroundColor="#F2F2F7"
                        barStyle='dark-content'>
                    </StatusBar>

                    <View style={{ width: '88%', marginTop: 44, marginBottom: 220 }}>
                        <TouchableOpacity onPress={() => props.navProp.goBack()} style={{width: '25%', marginVertical: 20}}>
                            <Ionicons name="arrow-back" size={32} />
                        </TouchableOpacity>
                        <Text style={[Styles.GeneralHeaderText, { marginBottom: 8}]}>Friends</Text>

                        <ScrollView horizontal={true} style={{ width: "100%", flexDirection: 'column'}}>
                            <FlatList
                                scrollEnabled={false}
                                data={friends}
                                renderItem={renderItem}
                                keyExtractor={(item, index) => {return item.phone;}}
                            />
                        </ScrollView>




                    </View>
                </View>
            </View>
        </ScrollView>
    );
}