// By: Patrick Karangwa
// This page allows the passenger to call a number that offers alternative
// transportation resources in case they want to use other means of transportation.
// This page also provides them with a summary of what the resource offers.
import { Text, View, TouchableOpacity, Platform, Linking, Image} from 'react-native';
import React, {useState} from 'react';
import Styles from '../shared/styles/Styles';
import Header from '../components/Header';

export default function LocalResources(props) {
    props.navProp.setOptions({ header: () => <Header navProp={props.navProp} pageTitle={props.userProp} />})

    // This function allows the app to connect with the user's phone
    // allows them to make a call.
    makeCall = () => {
        let phoneNumber = '';
        if (Platform.OS == 'android'){
            phoneNumber = 'tel:${1234567890}';
        }
        else{
            phoneNumber = 'telprompt:${1234567890}';
        }
        Linking.openURL(phoneNumber);
    };
    // Initializing different states to control whether details are shown
    // or not.
    const [hiddenContent_A, setHiddenContent_A] = useState(false);
    const [hiddenContent_B, setHiddenContent_B] = useState(false);
    const [hiddenContent_C, setHiddenContent_C] = useState(false);
    return (
        <View style={Styles.container}>
            <View style={{ width: '100%', alignItems: 'center', marginTop: 20}}>
            <Text style={{ marginVertical: 20, width: '90%', textAlign: 'center', fontSize: 20, fontWeight: '600'}}>
            Click the phone icon to call a transportation resource. 
            Click elsewhere on the button to see more details.
            </Text>
            </View>

            <View style={Styles.resourceTopCluster}>
                <TouchableOpacity 
                style={Styles.ResourceButton}
                onPress={() => setHiddenContent_A(!hiddenContent_A)}
                >
                    <Text style={Styles.ButtonText}>Resource A</Text>
                    <TouchableOpacity onPress={makeCall}>
                        <Image style={Styles.PhoneIcon} 
                        source={require('../assets/phoneIcon.png')}>
                        </Image>
                    </TouchableOpacity> 
                </TouchableOpacity>

                {/* This expression checks whether the state is set to true
                or false to allow the content to be shown or hidden respectively.*/}
                {hiddenContent_A ? 
                    (
                        <Text style={Styles.GeneralText}>Details for Resource A</Text>
                    ) : null
                }


                <TouchableOpacity 
                style={Styles.ResourceButton}
                onPress={() => setHiddenContent_B(!hiddenContent_B)}
                >
                    <Text style={Styles.ButtonText}>Resource B</Text>
                    <TouchableOpacity onPress={makeCall}>
                        <Image style={Styles.PhoneIcon} 
                        source={require('../assets/phoneIcon.png')}>
                        </Image>
                    </TouchableOpacity>
                </TouchableOpacity>

                {hiddenContent_B ? 
                    (
                        <Text style={Styles.GeneralText}>Details for Resource B</Text>
                    ) : null
                }


                <TouchableOpacity 
                style={Styles.ResourceButton}
                onPress={() => setHiddenContent_C(!hiddenContent_C)}
                >
                    <Text style={Styles.ButtonText}>Resource C</Text>
                    <TouchableOpacity onPress={makeCall}>
                        <Image style={Styles.PhoneIcon} 
                        source={require('../assets/phoneIcon.png')}>
                        </Image>
                    </TouchableOpacity>
                </TouchableOpacity>

                {hiddenContent_C ? 
                    (
                        <Text style={Styles.GeneralText}>Details for Resource C</Text>
                    ) : null
                }

            </View>

        </View>
    );
}