// By Patrick Karangwa
// This is the initial page for both the driver and passenger. This page will help the user who is a first-timer
// to create a new account or if they are an existing user, sign-in with either an email address or phone number
// and a password.
//Credential verification by Emily Lea
import { Text, View, TouchableOpacity, TextInput, StatusBar, KeyboardAvoidingView, Platform} from 'react-native';
import React, { Component } from 'react';
import Styles from '../shared/styles/Styles';
import Divider from 'react-native-divider';
//added by Emily for setting Expo push token
import * as Device from 'expo-device';
import * as Notifications from 'expo-notifications';

//export default function Login(props) {
export class Login extends Component {
    constructor(props) {
        super(props);
        this.state = {
            user: "",
            password: "",
            token: ""
        };
    }

    //get the user's Expo token
    async componentDidMount() {
        const generated_token = (await Notifications.getExpoPushTokenAsync()).data;
        this.setState({token: generated_token});
        console.log("This is the generated token from sign in: " + generated_token);
    }

    render() {
        return (
            <KeyboardAvoidingView behavior={Platform.OS === "ios" ? "padding" : "height"} style={Styles.loginWrapper}>
                <View style={Styles.loginContainer}>
                    <StatusBar
                        backgroundColor="#F2F2F7"
                        barStyle='dark-content'>
                    </StatusBar>

                    <Text style={[Styles.LargeGeneralText, { color: '#466682' }]}>Please choose your role:</Text>

                    <TouchableOpacity
                        style={Styles.DriverButton}
                        onPress={() => this.props.navProp.navigate("Account Creation", { accountType: "driver" })}>
                        <Text style={Styles.ButtonText}>Driver</Text>
                    </TouchableOpacity>

                    <TouchableOpacity
                        style={Styles.PassengerButton}
                        onPress={() => this.props.navProp.navigate("Account Creation", { accountType: "passenger" })}>
                        <Text style={Styles.ButtonText}>Passenger</Text>
                    </TouchableOpacity>

                    <View
                        style={{
                            borderBottomColor: 'black',
                            borderBottomWidth: 5
                        }}></View>

                    <Divider borderColor="#466682" color="#466682" orientation="center">or</Divider>
                    <View style={{ marginBottom: 20 }}></View>

                    <Text style={[Styles.LargeGeneralText, { color: '#466682' }]}>Already have an account? Sign in below:</Text>

                    <View style={{ width: '85%' }}>
                        <TextInput
                            style={Styles.TextInputs}
                            placeholder='Email address or phone number'
                            placeholderTextColor='#8ba2c4'
                            onChangeText={(text) => this.setState({user: text})}
                        >
                        </TextInput>
                    </View>

                    <View style={{ width: '85%' }}>
                        <TextInput
                            style={Styles.TextInputs}
                            placeholder='Password'
                            placeholderTextColor='#8ba2c4'
                            onChangeText={(text) => this.setState({password: text})}
                            secureTextEntry
                        >
                        </TextInput>
                    </View>

                    <View style={{ marginBottom: 64 }}></View>

                    <TouchableOpacity
                        style={Styles.SigninButton}
                        onPress={() => {
                            // future: add error checking here for empty entries (i.e., unfilled email/phone/password) before getting token for an empty entry and fetching for an empty entry.
                            let specifications = {
                                method: 'POST',
                                headers: {
                                    'Accept': 'application/json',
                                    'Content-Type': 'application/json;charset=utf-8'
                                },
                                body: JSON.stringify(this.state)
                            }
                            // console.log(specifications);
                            fetch("https://magicdjangoapp.herokuapp.com/usercredentials/verify_credentials/", specifications)
                                .then(response => response.json())
                                .then(jsonResponse => {
                                    if (jsonResponse == "invalid") {
                                        alert("The credentials entered are invalid.");
                                    }
                                    else {
                                        if (jsonResponse[0]["account_type"] == "driver") {
                                            this.props.navProp.navigate("Driver Home", {driver: "driver", userProp: jsonResponse[1]["phone"]});
                                        }
                                        if (jsonResponse[0]["account_type"] == "passenger") {
                                           this.props.navProp.navigate("Passenger Home", {passenger: "passenger", userProp: jsonResponse[1]["phone"]});
                                        }
                                    }
                                })
                                .catch(error => console.log(error))
                        }}>
                        <Text style={Styles.SigninButtonText}>Sign In</Text>
                    </TouchableOpacity>
                </View>
            </KeyboardAvoidingView>
        );
    }
}