import React from 'react';
import { Text, View, Image, TouchableOpacity, StatusBar, Alert, ScrollView } from 'react-native';
import * as Location from 'expo-location';
import Styles from '../shared/styles/Styles';
import HelpModal from '../components/HelpModal';
import Header from '../components/Header';
import * as Notifications from 'expo-notifications';
import * as Device from 'expo-device';

//Handler to determine how notifications are handled when the app
//is in the foreground.
Notifications.setNotificationHandler({
  handleNotification: async () => ({
    shouldShowAlert: true,
    shouldPlaySound: false,
    shouldSetBadge: false,
  }),
});

//Some global variables
//let thisPassengerPhone = "4791112233"; //This is just for testing purposes
let driverInfo = {};

export default class PassengerHome extends React.Component {
  
  state = { 
    location: {},
    notification: {},
  };

  //Requesting permission to access notifications
  registerForPushNotificationsAsync = async() => {
    //Check for existing persmisions
    const {status: existingStatus} = await Notifications.getPermissionsAsync();
    let finalStatus = existingStatus;

    //If there are no existing permissions
    if (existingStatus !== 'granted'){
        const {status} = await Notifications.requestPermissionsAsync();
        finalStatus = existingStatus;
    }

    //If the permission is still not granted, exit the funciton
    if (finalStatus !== 'granted')
    {
        alert('Failed to get token for push notifications.');
        return;
    }
  }

  componentDidMount() {
    //Handling location
    this._getLocation();

    //Handling notifications
    this.registerForPushNotificationsAsync();
    Notifications.addNotificationReceivedListener(this._handleNotification);
    Notifications.addNotificationResponseReceivedListener(this._handleNotificationResponse);

    //used to pass phone number around to different pages
    this.props.navProp.setOptions({ header: () => <Header navProp={this.props.navProp} pageTitle={this.props.userProp} />})
  }

  //Location listener
  _getLocation = async () => {
    const { status } = await Location.requestForegroundPermissionsAsync();
    if(status != 'granted') { console.warn("Permission NOT granted..."); }
    const location = await Location.getCurrentPositionAsync();
    this.setState({ location });
  }

  //Notifications listeners
    _handleNotification = notification => {
    this.setState({ notification: notification });
  };

  _handleNotificationResponse = response => {

    // find out which notification it came from. friend/transportation/checkin?
    let notificationType = response.notification.request.content.data.notificationType;
    console.log("NOTIFICATION TYPE: "+notificationType);
    
    //Fetch information about the driver who sent the request
    let driverPhone = response.notification.request.content.data.phone;
    driverPhone = driverPhone
    console.log("Driver phone: " + driverPhone);
    let firstName = '';
    let lastName = '';
    let id = 0;
    let Name = '';
    let specifications = {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json;charset=utf-8'
      },
      body: JSON.stringify({'user' : driverPhone})
    };
    fetch("https://magicdjangoapp.herokuapp.com/drivers/find_driver/", specifications)
    .then(resp => resp.json())
    .then(jsonResponse => {
      let driverInfo = {};
      Object.entries(jsonResponse).forEach(([key, value]) => {
        if (key === 'first_name'){
          firstName = value;
          firstName = firstName.trim();
        }
        if (key === 'last_name'){
            lastName = value;
            lastName = lastName.trim();
        }
        if (key === 'phone'){
            id = value;
        }
        Name = firstName + ' ' + lastName;
          driverInfo = { Name, id };
      })
      if (notificationType === "checkin"){
        Alert.alert(driverInfo.Name + " is here!", "Your driver is at the requested pickup location.");
      }
      else if (notificationType === "friendrequest"){
        //start alert
        Alert.alert(
            driverInfo.Name + " has sent a you a friend request",
            "Phone number: " + driverInfo.id,
            [
                {
                    text: "Accept",
                    onPress: () => {
                        //Add the driver to the friends list with fetch POST
                        let specifications = {
                            method: 'POST',
                            headers: {
                                'Content-Type': 'application/json;charset=utf-8'
                            },
                            body: JSON.stringify({ "passenger_phone": this.props.userProp, "driver_phone": driverInfo.id })
                        }
                        fetch("https://magicdjangoapp.herokuapp.com/friends/add_friend/", specifications)
                            .then(response => response.json())
                            .then(jsonResponse => { console.log(jsonResponse);})
                            .catch(error => console.log("Call 2 error: " + error));
                    }
                },
                {
                    text: "Decline",
                    onPress: () => {
                        //Decline the driver's request with a POST request
                        let specifications = {
                            method: 'POST',
                            headers: {
                                'Content-Type': 'application/json;charset=utf-8'
                            },
                            body: JSON.stringify({ "passenger_phone": this.props.userProp, "driver_phone": driverInfo.id })
                        }
                        fetch("https://magicdjangoapp.herokuapp.com/friends/delete_friend/", specifications)
                            .catch(error => console.log("Call 3 error: " + error));
                    }
                }
            ]
        );
        //end alert
        }
    })
    .catch(error => console.log("Call 1 error: " + error));

    

  };

  render(){
    console.log("PassengerHome Number:"+number);
  
    let json = JSON.stringify(this.state.location);
    let json_parsed = JSON.parse(json);
    let coords_json = json_parsed["coords"] || "{}";
    let latitude = coords_json["latitude"];
    let longitude = coords_json["longitude"];
    let home_address = '';
    let number = this.props.userProp;
    console.log("PassengerHome Number:"+number);

    //get the home address from backend
    let specifications = {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json;charset=utf-8'
        },
        body: JSON.stringify({ 'phone': this.props.userProp })
    }
    fetch("https://magicdjangoapp.herokuapp.com/passengers/address/", specifications)
        .then(response => response.json())
        .then(jsonResponse => {
            home_address = jsonResponse[0];
        })
        .catch(error => console.log("Call 4 error: " + error))
    
    // console.log("Latitude:"+latitude);
    // console.log("Longitude:"+longitude);

    return (
      <View style={[Styles.container]}>
          <View style={Styles.passengerHomeBtnContainer}>
            <StatusBar
                  backgroundColor="#F2F2F7"
                  barStyle='dark-content'>
            </StatusBar>

            <View style={{ width: '85%', alignContent: 'center' }}>

              <View>
                <Text style={Styles.GeneralHeaderText}>Hello! </Text>
                <Text style={Styles.LargeGeneralText}>Where do you want to go today?</Text>
                <Text style={Styles.LargeGeneralText}>Please choose an option below:</Text>
                        <TouchableOpacity style={[Styles.passengerHomeBtnGeneral, Styles.passengerHomeBtn1]} onPress={() => this.props.navProp.navigate("Date Time Selector", {userProp: number, destinationTo: home_address, startLocation: 'Current Location', latitude: latitude, longitude: longitude })}>
                  <Text style={Styles.buttonText}>Go Home</Text>
                  <Image style={Styles.houseIcon} source={require('../assets/home.png')}></Image>
                </TouchableOpacity>
              </View>

              <View>
                <TouchableOpacity style={[Styles.passengerHomeBtnGeneral, Styles.passengerHomeBtn2]} onPress={() => this.props.navProp.navigate("Destination Selector", { userProp: number, latitude: latitude, longitude: longitude})}>
                  <Text style={Styles.buttonText}>Schedule a Trip</Text>
                  <Image style={Styles.carIcon} 
                    source={require('../assets/car.png')} 
                    ></Image>
                </TouchableOpacity>
              </View>

              <View>
                <TouchableOpacity style={[Styles.passengerHomeBtnGeneral, Styles.passengerHomeBtn3]} onPress={() => this.props.navProp.navigate("Local Resources", {userProp: this.props.userProp})}>
                  <Text style={Styles.buttonText}>Resources</Text>
                  <Image style={Styles.resourceIcon} source={require('../assets/resources3.png')}></Image>
                </TouchableOpacity>
              </View>
              
              <View style={{ marginBottom: 60 }}></View>

              <View style={Styles.helpBtnWrapper}>
                <HelpModal />
              </View>

            </View>

          </View>

          <View style={{ marginBottom: 30 }}></View>
      </View>
    );
  }
}