// Author: Alan Torres
// This page displays the seven days of the week where the driver can schedule their availability.

import { Text, View, ScrollView } from 'react-native';
import { React, useState, useEffect } from 'react';
import Styles from '../shared/styles/Styles';
import WeekDayScheduler from '../components/WeekDayScheduler';
import { LineChart } from "react-native-chart-kit";
import { Dimensions } from "react-native";
import HeaderDriver from '../components/HeaderDriver';
  

export default function ScheduleAvailability(props) {
    const [isLoading, setIsLoading] = useState(true);

    useEffect(() => {
        loadData();
        props.navProp.setOptions({ header: () => <HeaderDriver navProp={props.navProp} pageTitle={props.userProp} />})
    }, []);
    let driverPhoneNumber = props.userProp;
    const allTimeValuesArray = new Array;

    const [SundayStartTime, setSundayStartTime] = useState(new Date(2022, 6, 24, 8, 30));
    const [SundayEndTime, setSundayEndTime] = useState(new Date(2022, 6, 24, 15, 30));

    const [MondayStartTime, setMondayStartTime] = useState(new Date(2022, 6, 24, 13, 30));
    const [MondayEndTime, setMondayEndTime] = useState(new Date(2022, 6, 24, 19, 0));

    const [TuesdayStartTime, setTuesdayStartTime] = useState(new Date(2022, 6, 24, 8, 30));
    const [TuesdayEndTime, setTuesdayEndTime] = useState(new Date(2022, 6, 24, 8, 30));

    const [WednesdayStartTime, setWednesdayStartTime] = useState(new Date(2022, 6, 24, 10, 30));
    const [WednesdayEndTime, setWednesdayEndTime] = useState(new Date(2022, 6, 24, 19, 30));

    const [ThursdayStartTime, setThursdayStartTime] = useState(new Date(2022, 6, 24, 7, 45));
    const [ThursdayEndTime, setThursdayEndTime] = useState(new Date(2022, 6, 24, 10, 0));

    const [FridayStartTime, setFridayStartTime] = useState(new Date(2022, 6, 24, 16, 30));
    const [FridayEndTime, setFridayEndTime] = useState(new Date(2022, 6, 24, 20, 30));

    const [SaturdayStartTime, setSaturdayStartTime] = useState(new Date(2022, 6, 24, 11, 45));
    const [SaturdayEndTime, setSaturdayEndTime] = useState(new Date(2022, 6, 24, 14, 0));


    // Grab list of start and end times of each day of the week here
    let specifications = {
        method: 'GET',
        headers: {
            'Content-Type': 'application/json;charset=utf-8'
        },
    }
    const loadData = async () => {
        await fetch("https://magicdjangoapp.herokuapp.com/driverschedule/", specifications)
        .then(response => response.json())
        .then(jsonResponse => {
            jsonResponse.forEach(element => {
                if(element["phone"] == driverPhoneNumber){
                    let daysOfWeekListForTesting = [ "sunday", "monday", "tuesday", "wednesday", "thursday", "friday", "saturday" ];
                    daysOfWeekListForTesting.forEach(day => {
                        let db_hr = 0;
                        let db_min = 0;
                        let startAndEndTimes = element[day].split('-');

                        // grab start values:
                        let individualTimes = startAndEndTimes[0].split(' ');
                        if(individualTimes[1] == "PM")
                        {
                            if(individualTimes[0].split(':')[0] != "12")
                                db_hr+=12;
                        }
                        if(individualTimes[1] == "AM" && individualTimes[0].split(':')[0] == "12")
                            db_hr = 0;
                        else
                            db_hr+=parseInt(individualTimes[0].split(':')[0]);
                        db_min=parseInt(individualTimes[0].split(':')[1]);
                        allTimeValuesArray.push(db_hr);
                        allTimeValuesArray.push(db_min);

                        // grab end values:
                        db_hr = 0;
                        db_min = 0;
                        let individualTimesEnd = startAndEndTimes[1].split(' ');
                        if(individualTimesEnd[1] == "PM")
                        {
                            if(individualTimesEnd[0].split(':')[0] != "12")
                                db_hr+=12;
                        }
                        if(individualTimesEnd[1] == "AM" && individualTimesEnd[0].split(':')[0] == "12")
                            db_hr = 0;
                        else
                            db_hr+=parseInt(individualTimesEnd[0].split(':')[0]);
                        db_min=parseInt(individualTimesEnd[0].split(':')[1]);
                        allTimeValuesArray.push(db_hr);
                        allTimeValuesArray.push(db_min);
                    })
                }
            });
            setSundayStartTime(new Date(2022, 6, 24, allTimeValuesArray[0], allTimeValuesArray[1]));
            setSundayEndTime(new Date(2022, 6, 24, allTimeValuesArray[2], allTimeValuesArray[3]));

            setMondayStartTime(new Date(2022, 6, 24, allTimeValuesArray[4], allTimeValuesArray[5]));
            setMondayEndTime(new Date(2022, 6, 24, allTimeValuesArray[6], allTimeValuesArray[7]));

            setTuesdayStartTime(new Date(2022, 6, 24, allTimeValuesArray[8], allTimeValuesArray[9]));
            setTuesdayEndTime(new Date(2022, 6, 24, allTimeValuesArray[10], allTimeValuesArray[11]));

            setWednesdayStartTime(new Date(2022, 6, 24, allTimeValuesArray[12], allTimeValuesArray[13]));
            setWednesdayEndTime(new Date(2022, 6, 24, allTimeValuesArray[14], allTimeValuesArray[15]));
            
            setThursdayStartTime(new Date(2022, 6, 24, allTimeValuesArray[16], allTimeValuesArray[17]));
            setThursdayEndTime(new Date(2022, 6, 24, allTimeValuesArray[18], allTimeValuesArray[19]));

            setFridayStartTime(new Date(2022, 6, 24, allTimeValuesArray[20], allTimeValuesArray[21]));
            setFridayEndTime(new Date(2022, 6, 24, allTimeValuesArray[22], allTimeValuesArray[23]));

            setSaturdayStartTime(new Date(2022, 6, 24, allTimeValuesArray[24], allTimeValuesArray[25]));
            setSaturdayEndTime(new Date(2022, 6, 24, allTimeValuesArray[26], allTimeValuesArray[27]));
        })
        .catch(error => console.log(error))
        setIsLoading(false);
    }


    // line chart configuration
    // const screenWidth = Dimensions.get("window").width;
    const screenWidth = Dimensions.get("window").width;
    // const chartConfig = {
    const chartConfig = {
        backgroundGradientFrom: "#ffffff",
        backgroundGradientTo: "#ffffff",
        color: (opacity = 1) => `rgba(20, 43, 56, ${opacity})`,
        strokeWidth: 1, 
        barPercentage: 0.5,
        useShadowColorFromDataset: true,
        fillShadowGradient: "#edf7ff",
        fillShadowGradientOpacity: 0.44
      };

    // formatted start times for chart
    let sundayStartInt = parseFloat(SundayStartTime.getHours() + parseFloat(SundayStartTime.getMinutes() / 60.0));
    let mondayStartInt = parseFloat(MondayStartTime.getHours() + parseFloat(MondayStartTime.getMinutes() / 60.0));
    let tuesdayStartInt = parseFloat(TuesdayStartTime.getHours() + parseFloat(TuesdayStartTime.getMinutes() / 60.0));
    let wednesdayStartInt = parseFloat(WednesdayStartTime.getHours() + parseFloat(WednesdayStartTime.getMinutes() / 60.0));
    let thursdayStartInt = parseFloat(ThursdayStartTime.getHours() + parseFloat(ThursdayStartTime.getMinutes() / 60.0));
    let fridayStartInt = parseFloat(FridayStartTime.getHours()+ parseFloat(FridayStartTime.getMinutes() / 60.0));
    let saturdayStartInt = parseFloat(SaturdayStartTime.getHours() + parseFloat(SaturdayStartTime.getMinutes() / 60.0));

    // formatted end times for chart
    let sundayEndInt = parseFloat(SundayEndTime.getHours() + parseFloat(SundayEndTime.getMinutes() / 60.0));
    let mondayEndInt = parseFloat(MondayEndTime.getHours() + parseFloat(MondayEndTime.getMinutes() / 60.0));
    let tuesdayEndInt = parseFloat(TuesdayEndTime.getHours() + parseFloat(TuesdayEndTime.getMinutes() / 60.0));
    let wednesdayEndInt = parseFloat(WednesdayEndTime.getHours() + parseFloat(WednesdayEndTime.getMinutes() / 60.0));
    let thursdayEndInt = parseFloat(ThursdayEndTime.getHours() + parseFloat(ThursdayEndTime.getMinutes() / 60.0));
    let fridayEndInt = parseFloat(FridayEndTime.getHours() + parseFloat(FridayEndTime.getMinutes() / 60.0));
    let saturdayEndInt = parseFloat(SaturdayEndTime.getHours() + parseFloat(SaturdayEndTime.getMinutes() / 60.0));


    // more line chart configuration
    // const data = {
    const data = {
    labels: ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"],
    datasets: [
        {
        data: [sundayStartInt, mondayStartInt, tuesdayStartInt, wednesdayStartInt, thursdayStartInt, fridayStartInt, saturdayStartInt],
        color: (opacity = 1) => `rgba(52, 165, 235, ${opacity})`, // optional
        strokeWidth: 0, // optional
        },
        {
        data: [sundayEndInt, mondayEndInt, tuesdayEndInt, wednesdayEndInt, thursdayEndInt, fridayEndInt, saturdayEndInt],
        color: (opacity = 1) => `rgba(108, 54, 235, ${opacity})`, // optional
        strokeWidth: 0, // optional 
        },
        {
            data: [24],
            color: (opacity = 1) => `rgba(237, 247, 255, ${opacity})`,
            strokeWidth: 0,
        }
    ],
    legend: ["Start Times", "End Times"] // optional
    };

    if(isLoading){
        return(
            <View style={{flex: 1}}>
                <Text style={{textAlign: 'center', marginTop: 44}}>Loading Schedule...</Text>
            </View>
        );
    }
    else{
    return (
        <ScrollView>
            <View style={[Styles.general, {justifyContent: 'flex-start'}]}>
                <View style={{width: "85%", alignItems: 'center', marginBottom: 20}}></View>
                <View style={{width: '100%', alignItems: 'center', justifyContent: 'center', backgroundColor: '#ffffff', width: '92.75%', borderTopLeftRadius: 8, borderTopRightRadius: 8}}>
                    <Text style={{fontSize: 24, marginVertical: 28,color: '#3d8eff', fontWeight: '700'}}>Overview of Week:</Text>
                </View>
                
                <LineChart
                    data={data}
                    width={screenWidth*0.93}
                    height={screenWidth*0.93}
                    segments={12}
                    chartConfig={chartConfig}
                    fromZero={true}
                />
                
                <View style={Styles.scheduleAvailabilityOverviewTimes}>
                    <View style={{alignItems: 'flex-start'}}>
                        <View style={Styles.scheduleAvailabilityOverviewRows}>
                            <Text style={Styles.scheduleAvailabilityOverviewTimesDayNames}>Sunday: </Text>
                            <Text style={Styles.scheduleAvailabilityOverviewTimesDayTimes}>{((SundayStartTime.getHours()+11)%12+1)+":"+((SundayStartTime.getMinutes()).toString().length ==1?('0'+SundayStartTime.getMinutes()):(SundayStartTime.getMinutes()))+((SundayStartTime.getHours())>=12?" pm":" am")}  -  {((SundayEndTime.getHours()+11)%12+1)+":"+((SundayEndTime.getMinutes()).toString().length ==1?('0'+SundayEndTime.getMinutes()):(SundayEndTime.getMinutes()))+((SundayEndTime.getHours())>=12?" pm":" am")}</Text>
                        </View>
                        <View style={Styles.scheduleAvailabilityOverviewRows}>
                            <Text style={Styles.scheduleAvailabilityOverviewTimesDayNames}>Monday: </Text> 
                            <Text style={Styles.scheduleAvailabilityOverviewTimesDayTimes}>{((MondayStartTime.getHours()+11)%12+1)+":"+((MondayStartTime.getMinutes()).toString().length ==1?('0'+MondayStartTime.getMinutes()):(MondayStartTime.getMinutes()))+((MondayStartTime.getHours())>=12?" pm":" am")}  -  {((MondayEndTime.getHours()+11)%12+1)+":"+((MondayEndTime.getMinutes()).toString().length ==1?('0'+MondayEndTime.getMinutes()):(MondayEndTime.getMinutes()))+((MondayEndTime.getHours())>=12?" pm":" am")}</Text>
                        </View>
                        <View style={Styles.scheduleAvailabilityOverviewRows}>
                            <Text style={Styles.scheduleAvailabilityOverviewTimesDayNames}>Tuesday: </Text> 
                            <Text style={Styles.scheduleAvailabilityOverviewTimesDayTimes}>{((TuesdayStartTime.getHours()+11)%12+1)+":"+((TuesdayStartTime.getMinutes()).toString().length ==1?('0'+TuesdayStartTime.getMinutes()):(TuesdayStartTime.getMinutes()))+((TuesdayStartTime.getHours())>=12?" pm":" am")}  -  {((TuesdayEndTime.getHours()+11)%12+1)+":"+((TuesdayEndTime.getMinutes()).toString().length ==1?('0'+TuesdayEndTime.getMinutes()):(TuesdayEndTime.getMinutes()))+((TuesdayEndTime.getHours())>=12?" pm":" am")}</Text>
                        </View>
                        <View style={Styles.scheduleAvailabilityOverviewRows}>
                            <Text style={Styles.scheduleAvailabilityOverviewTimesDayNames}>Wednesday: </Text> 
                            <Text style={Styles.scheduleAvailabilityOverviewTimesDayTimes}>{((WednesdayStartTime.getHours()+11)%12+1)+":"+((WednesdayStartTime.getMinutes()).toString().length ==1?('0'+WednesdayStartTime.getMinutes()):(WednesdayStartTime.getMinutes()))+((WednesdayStartTime.getHours())>=12?" pm":" am")}  -  {((WednesdayEndTime.getHours()+11)%12+1)+":"+((WednesdayEndTime.getMinutes()).toString().length ==1?('0'+WednesdayEndTime.getMinutes()):(WednesdayEndTime.getMinutes()))+((WednesdayEndTime.getHours())>=12?" pm":" am")}</Text>
                        </View>
                        <View style={Styles.scheduleAvailabilityOverviewRows}>
                            <Text style={Styles.scheduleAvailabilityOverviewTimesDayNames}>Thursday: </Text> 
                            <Text style={Styles.scheduleAvailabilityOverviewTimesDayTimes}>{((ThursdayStartTime.getHours()+11)%12+1)+":"+((ThursdayStartTime.getMinutes()).toString().length ==1?('0'+ThursdayStartTime.getMinutes()):(ThursdayStartTime.getMinutes()))+((ThursdayStartTime.getHours())>=12?" pm":" am")}  -  {((ThursdayEndTime.getHours()+11)%12+1)+":"+((ThursdayEndTime.getMinutes()).toString().length ==1?('0'+ThursdayEndTime.getMinutes()):(ThursdayEndTime.getMinutes()))+((ThursdayEndTime.getHours())>=12?" pm":" am")}</Text>
                        </View>
                        <View style={Styles.scheduleAvailabilityOverviewRows}>
                            <Text style={Styles.scheduleAvailabilityOverviewTimesDayNames}>Friday: </Text> 
                            <Text style={Styles.scheduleAvailabilityOverviewTimesDayTimes}>{((FridayStartTime.getHours()+11)%12+1)+":"+((FridayStartTime.getMinutes()).toString().length ==1?('0'+FridayStartTime.getMinutes()):(FridayStartTime.getMinutes()))+((FridayStartTime.getHours())>=12?" pm":" am")}  -  {((FridayEndTime.getHours()+11)%12+1)+":"+((FridayEndTime.getMinutes()).toString().length ==1?('0'+FridayEndTime.getMinutes()):(FridayEndTime.getMinutes()))+((FridayEndTime.getHours())>=12?" pm":" am")}</Text>
                        </View>
                        <View style={[Styles.scheduleAvailabilityOverviewRows, {borderBottomWidth: 0}]}>
                            <Text style={Styles.scheduleAvailabilityOverviewTimesDayNames}>Saturday:</Text> 
                            <Text style={Styles.scheduleAvailabilityOverviewTimesDayTimes}>{((SaturdayStartTime.getHours()+11)%12+1)+":"+((SaturdayStartTime.getMinutes()).toString().length ==1?('0'+SaturdayStartTime.getMinutes()):(SaturdayStartTime.getMinutes()))+((SaturdayStartTime.getHours())>=12?" pm":" am")}  -  {((SaturdayEndTime.getHours()+11)%12+1)+":"+((SaturdayEndTime.getMinutes()).toString().length ==1?('0'+SaturdayEndTime.getMinutes()):(SaturdayEndTime.getMinutes()))+((SaturdayEndTime.getHours())>=12?" pm":" am")}</Text>
                        </View>
                    </View>
                </View>

                <View style={{ marginVertical: 20 }}></View>
                <View style={{width: "93%", alignItems: 'center', marginBottom: 10}}>
                    <Text style={{ fontWeight: '700', fontSize: 20, alignSelf: 'flex-start'}}>Full Schedule:</Text>
                </View>

                <WeekDayScheduler dayOfWeek='Sunday' startTime={SundayStartTime} endTime={SundayEndTime} changeStartDate={SundayStartTime => setSundayStartTime(SundayStartTime)} changeEndDate={SundayEndTime => setSundayEndTime(SundayEndTime)} driverPhoneNumber={driverPhoneNumber}/>
                <WeekDayScheduler dayOfWeek='Monday' startTime={MondayStartTime} endTime={MondayEndTime} changeStartDate={MondayStartTime => setMondayStartTime(MondayStartTime)} changeEndDate={MondayEndTime => setMondayEndTime(MondayEndTime)} driverPhoneNumber={driverPhoneNumber}/>
                <WeekDayScheduler dayOfWeek='Tuesday' startTime={TuesdayStartTime} endTime={TuesdayEndTime} changeStartDate={TuesdayStartTime => setTuesdayStartTime(TuesdayStartTime)} changeEndDate={TuesdayEndTime => setTuesdayEndTime(TuesdayEndTime)} driverPhoneNumber={driverPhoneNumber}/>
                <WeekDayScheduler dayOfWeek='Wednesday' startTime={WednesdayStartTime} endTime={WednesdayEndTime} changeStartDate={WednesdayStartTime => setWednesdayStartTime(WednesdayStartTime)} changeEndDate={WednesdayEndTime => setWednesdayEndTime(WednesdayEndTime)} driverPhoneNumber={driverPhoneNumber}/>
                <WeekDayScheduler dayOfWeek='Thursday' startTime={ThursdayStartTime} endTime={ThursdayEndTime} changeStartDate={ThursdayStartTime => setThursdayStartTime(ThursdayStartTime)} changeEndDate={ThursdayEndTime => setThursdayEndTime(ThursdayEndTime)} driverPhoneNumber={driverPhoneNumber}/>
                <WeekDayScheduler dayOfWeek='Friday' startTime={FridayStartTime} endTime={FridayEndTime} changeStartDate={FridayStartTime => setFridayStartTime(FridayStartTime)} changeEndDate={FridayEndTime => setFridayEndTime(FridayEndTime)} driverPhoneNumber={driverPhoneNumber}/>
                <WeekDayScheduler dayOfWeek='Saturday' startTime={SaturdayStartTime} endTime={SaturdayEndTime} changeStartDate={SaturdayStartTime => setSaturdayStartTime(SaturdayStartTime)} changeEndDate={SaturdayEndTime => setSaturdayEndTime(SaturdayEndTime)} driverPhoneNumber={driverPhoneNumber}/>
                <View style={{marginBottom: 100}}></View>
            </View>
        </ScrollView>
    );
    }
}
