//Users can edit their personal and notification preferences
//Navigation will be added in the nav bar
//by Emily Lea
import { Text, View, TextInput, ScrollView, Pressable, TouchableOpacity, StatusBar, Alert } from 'react-native';
import React, { Component } from 'react';
import Checkbox from '../components/Checkbox/index';
import UploadImage from '../components/UploadImage/UploadImage';
import Styles from '../shared/styles/Styles';
import { Ionicons } from '@expo/vector-icons';


export class Settings extends Component {
    constructor(props) {
        super(props);
        this.accountType = '';
        //add user prop here
        this.CheckboxElement = React.createRef();//ref to get true/false value of checkbox
        this.ImageUploaderElement = React.createRef();//this will be set by the UploadImage.js
        this.state = {
            userInformation: '',
            userPhoto: null
        };
    }

    async componentDidMount() {
        // use phone number to get accountType
        let driver_or_passenger_specifications = {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json;charset=utf-8'
            },
            body: JSON.stringify({ "phone": this.props.userProp})
        }
        this.accountType = await fetch("https://magicdjangoapp.herokuapp.com/users/get_by_phone/", driver_or_passenger_specifications)
        .then(response => response.json())
        .then(jsonResponse => { return (jsonResponse["driver_or_passenger"].trimEnd())})

        let specifications = {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json;charset=utf-8'
            },
            body: JSON.stringify({ "user": this.props.userProp })
        };
        if (this.accountType == "driver") {
            //get text field data
            const textFields = await fetch("https://magicdjangoapp.herokuapp.com/drivers/find_driver/", specifications)
                .then(response => response.json())
                .then(jsonResponse => { return jsonResponse })
                .catch(error => console.log(error))
            this.setState({ userInformation: textFields });
            //get photo
            const photo = await fetch("https://magicdjangoapp.herokuapp.com/images/find_image/", specifications)
                .then(response => response.json())
                .then(jsonResponse => { return jsonResponse.uri })
                .catch(error => console.log(error))
            this.setState({ userPhoto: photo.trimEnd() });
        }
        if (this.accountType == "passenger") {
            //get text field data
            const textFields = await fetch("https://magicdjangoapp.herokuapp.com/passengers/find_passenger/", specifications)
                .then(response => response.json())
                .then(jsonResponse => { return jsonResponse; })
                .catch(error => console.log(error))
            delete textFields["starting_location"];
            this.setState({ userInformation: textFields })
            //get photo
            const photo = await fetch("https://magicdjangoapp.herokuapp.com/images/find_image/", specifications)
                .then(response => response.json())
                .then(jsonResponse => { return jsonResponse.uri })
                .catch(error => console.log(error))
            this.setState({ userPhoto: photo.trimEnd() });
        }
    }

    render() {

        var passengerTextFieldLabels = {
            "first_name": "First Name",
            "last_name": "Last Name",
            "home_address": "Home Address",
            "email_address": "Email Address",
            "phone": "Phone"
        };

        var driverTextFieldLabels = {
            "first_name": "First Name",
            "last_name": "Last Name",
            "email_address": "Email Address",
            "phone": "Phone",
            "plate_number": "License Plate Number",
            "vehicle_make": "Vehicle Make",
            "vehicle_model": "Vehicle Model"
        };

        var textFieldLabels;
        var apiInformation = {};
        if (this.accountType == "driver") {
            textFieldLabels = driverTextFieldLabels;
        }
        if (this.accountType == "passenger") {
            textFieldLabels = passengerTextFieldLabels;
        }

        function needsCheckbox(accountType, boxLabel, ref, isWheelchairAccessible) {
            if (accountType == "driver") {
                if (isWheelchairAccessible == "yes") {
                    ref.current = true;
                }
                else {
                    ref.current = false;
                }
                return (
                    <Checkbox forwardRef={ref} boxLabel={boxLabel}></Checkbox>
                )
            }
        }

        function updateAccountInformation(checkboxRef, imageUploaderRef, userInformation, accountType/*, nav*/) {
            var invalidFields = "";
            var userAccountType = accountType;
            for (var key in userInformation) {
                if (userInformation[key] == "") {
                    invalidFields = invalidFields.concat("\n" + key);
                }
            }
            //photo
            if (userAccountType == "driver") {
                apiInformation["uri"] = imageUploaderRef.current;
            }
            if (userAccountType == "passenger") {
                apiInformation["uri"] = imageUploaderRef.current;
            }
            //check that all required fields have information
            if (invalidFields != "") {
                alert("The following information is required to create an account:" + invalidFields);
            }
            else {
                //driver accounts
                if (userAccountType == "driver") {
                    apiInformation["driver_or_passenger"] = "driver";
                    //wheelchair access
                    if (checkboxRef.current) {
                        apiInformation["wheelchair_accessible"] = "yes";
                    }
                    else {
                        apiInformation["wheelchair_accessible"] = "no";
                    }
                }
                //passenger accounts
                else {
                    apiInformation["driver_or_passenger"] = "passenger";
                }
                //fetch API call to update user information
                let specifications = {
                    method: 'POST',
                    headers: {
                        'Accept': 'application/json',
                        'Content-Type': 'application/json;charset=utf-8'
                    },
                    body: JSON.stringify(apiInformation)
                }
                fetch("https://magicdjangoapp.herokuapp.com/users/update_user/", specifications)
                    .then(response => response.json())
                    .then(jsonResponse => {
                        Alert.alert("Update successful!", jsonResponse);
                    })
                    .catch(error => console.log(error))
                //end fetch
            }
        }

        return (
            <View style={Styles.general}>
            <ScrollView style={{ width: '85%', marginTop: 40 }} showsVerticalScrollIndicator={false}>
                <StatusBar
                    backgroundColor='#F2F2F7'
                    barStyle='dark-content'>
                </StatusBar>
                    <TouchableOpacity onPress={() => this.props.navProp.goBack()} style={{width: '25%', marginVertical: 20}}>
                        <Ionicons name="arrow-back" size={32} />
                    </TouchableOpacity>
                    <Text style={Styles.GeneralHeaderText}>Profile Information</Text>
                    <Text style={{ fontSize: 20, fontWeight: 'bold', marginBottom: 10 }}>Click the box below to upload a different image: </Text>
                    <View style={{ width: '100%', alignItems: 'center'}}>
                        <UploadImage forwardRef={this.ImageUploaderElement} accountType={this.accountType} image={this.state.userPhoto}></UploadImage>
                    </View>
                    {
                        //fetch; load the user's information into the text boxes
                        //start
                        Object.entries(this.state.userInformation).map(([key, value]) => {
                            apiInformation[key] = value.trimEnd();
                            if (key != "wheelchair_accessible") {
                                if (key != "phone") {
                                    return (
                                        <View key={key}>
                                            <Text style={{ fontSize: 20 }}>{textFieldLabels[key]}</Text>
                                            <TextInput
                                                placeholder={value.trimEnd()}
                                                onChangeText={(text) => { apiInformation[key] = text }}
                                                style={Styles.TextInputs}>
                                            </TextInput>
                                        </View>
                                    )
                                }
                                else {
                                    apiInformation["current_phone"] = value;
                                    apiInformation["new_phone"] = value;
                                    return (
                                        <View key={key}>
                                            <Text style={{ fontSize: 20 }}>{textFieldLabels[key]}</Text>
                                            <TextInput
                                                placeholder={value.trimEnd()}
                                                onChangeText={(text) => { apiInformation["new_phone"] = text }}
                                                style={Styles.TextInputs}>
                                            </TextInput>
                                        </View>
                                    )
                                }
                            }
                            else {
                                return (
                                    <View style={Styles.WheelChairAccessibleBox} key={key}>
                                        {needsCheckbox(this.accountType, "Wheelchair Accessible: ", this.CheckboxElement, value)}
                                    </View>
                                )
                            }
                        }
                        )
                    }
                    <View style={{ width: '100%', marginBottom: 80 }}>
                        <View style={{ width: '50%', right: 35, marginTop: 16 }}>
                            <Pressable style={Styles.NextButton} onPress={() => updateAccountInformation(this.CheckboxElement, this.ImageUploaderElement, this.state.userInformation, this.accountType/*, this.props.navProp*/)}><Text style={Styles.NextButtonText}>Update</Text></Pressable>
                        </View>
                    </View>
                </ScrollView>
            </View>
        )
    }
}