//Author: Patrick Page
//TripPlanner.js : Screen that app takes a passenger to when they want to plan a trip
//

import { ScrollView, Text, View, Image, TouchableOpacity, StatusBar, FlatList, Alert } from 'react-native';
import { React, useState, useEffect } from 'react';
import Styles from '../shared/styles/Styles';
import { MaterialIcons } from '@expo/vector-icons';
import {Entypo} from '@expo/vector-icons';
import Header from '../components/Header';

const DriverListItem = ({ item, onPress, backgroundColor, textColor }) => {
    return (
    <TouchableOpacity 
        onPress={onPress} 
        style={[Styles.driverListItem,backgroundColor]}>
            <Image style={Styles.accountIcon} source={require('../assets/account.png')} />
            <Text style={[Styles.driverListTitle, textColor]}>{item.name}</Text>
    </TouchableOpacity>
    )
};

const FilterButton = ({ item, onPress, backgroundColor, textColor }) => {
    return (
    <TouchableOpacity 
        onPress={onPress} 
        style={[Styles.driverFilterButton,backgroundColor]}>
            <Text style={[Styles.filterButtonText, textColor]}>{item.name}</Text>
    </TouchableOpacity>
    )
};

export default function TripPlanner(props) {
    useEffect(() => {
    props.navProp.setOptions({ header: () => <Header navProp={props.navProp} pageTitle={props.userProp} />})
    }, []);

    let phoneNumber = props.userProp;
    let formattedDate = props.dateProp;
    let formattedTime = props.timeProp;
    let destinationTo = props.destinationProp;
    let startingFrom = props.startingLocationProp;
    let latitude = props.currentLatitudeProp;
    let longitude = props.currentLongitudeProp;
    console.log("Destination: " + destinationTo);
    console.log("Starting: " + startingFrom);
    console.log("Lat: " + latitude);
    console.log("Long: " + longitude);

    // console.log("Trip Plan Phone:"+phoneNumber);
    // console.log("Trip Plan Date:"+formattedDate);
    // console.log("Trip Plan Time:"+formattedTime);
    var dateAndTime = {
        "date": formattedDate,
        "time": formattedTime
    }
    var params = {
        "passenger_phone": phoneNumber,
        "date": formattedDate,
        "time": formattedTime
    }

    const [driversLoaded, setDriversLoaded] = useState(false);
    const [filterId, setFilterId] = useState(null);
    const [selectedId, setSelectedId] = useState(null);
    const [filter, setFilter] = useState([
        {name: 'Family and Friend Drivers', id: 1},
        {name: 'Non-Family and Friend Drivers', id: 2},
        {name: 'All Drivers', id: 3}
    ]);
    const [selectedFilter, setSelectedFilter] = useState([
        {name: 'All Drivers', id: 3}
    ]);
    const [ selectedDriver, setSelectedDriver ] = useState([
        {name: null, friend: null, id: null}
    ]); 
    const [driver, addDriver] = useState([
    ]);

    let firstName = '';
    let lastName = '';
    let name = '';
    let currentDriver = {};
    let id = 0;

    useEffect(() => {
        setFilterId(3)
        let specifications = {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json;charset=utf-8'
            },
            body: JSON.stringify(dateAndTime)
        }
        fetch("https://magicdjangoapp.herokuapp.com/driverschedule/available_drivers/", specifications)
            .then(response => response.json())
            .then(jsonResponse => {
                jsonResponse.forEach(object => {
                    Object.entries(object).forEach(([key, value]) => {
                        if(key === 'first_name'){
                            firstName = value;
                            firstName = firstName.trim();
                        }
                        if(key === 'last_name'){
                            lastName = value;
                            lastName = lastName.trim();
                        }
                        if(key === 'phone'){
                            id = value;
                        }
                        name = firstName + ' ' + lastName;
                        currentDriver = {name, id};

                        addDriver((prevDrivers) => {
                            return [...prevDrivers.filter(driver => driver.id != id), currentDriver]
                        });
                    });
                });
                setDriversLoaded(true);
            })
            .catch(error => console.log("Call 1 error: "+error))
    }, []);

    useEffect(() => {
        // console.log(JSON.stringify(selectedFilter));
        filterBy(selectedFilter);
    }, [selectedFilter]);

    useEffect(() => {
        // console.log(JSON.stringify(selectedDriver));
    }, [selectedDriver]);

    const renderItem = ({ item }) => {
        const backgroundColor = item.id === selectedId ? '#4484eb' : '#ffffff';
        const color = item.id === selectedId ? '#FFFFFF' : '#000000';
        return (
            <DriverListItem 
                item={item}
                onPress={() => {
                    setSelectedId(item.id);
                    setSelectedDriver(item);
                    }
                }
                backgroundColor={{ backgroundColor }}
                textColor={{ color }}
            />
        );
    }

    const renderFilterButton = ({ item }) => {
        const backgroundColor = item.id === filterId ? '#4f72f0' : '#ffffff';
        const color = item.id === filterId ? '#FFFFFF' : '#2b2b2b';
        return (
            <FilterButton
                item={item}
                onPress={() => {
                    setFilterId(item.id);
                    setSelectedFilter(item);
                    }
                }
                backgroundColor={{ backgroundColor }}
                textColor={{ color }}
            />
        
        );
    }

    const submitRequest = () => {
        // for future notification API call:
        //   if current location: use latitude and longitude
        //   else: convert 'startingFrom' address into latitude and longitude values, then use those
        // might also need to convert destinationTo address to latitude/longitude 
        // console.log(selectedId);
        console.log("LAT: "+latitude);
        console.log("LONG: "+ longitude);
        console.log("START: "+startingFrom);

        // need some error checking here: if user doesn't choose a driver, dont let them request. Alert.alert("Please choose a driver, etc....")
        if(selectedId == null){
            Alert.alert("Please choose a driver.", "If no drivers are available, please go back and update your date/time and try again.");
        }
        
        //----------------------------------------------------------------------------------------------------
        // SENDING A REQUEST TO THE  DRIVER
        else{
            console.log("Selected driver: "+selectedId);
            //Specifications for the POST request
            let specifications = {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json;charset=utf-8'
                },
                body: JSON.stringify({"user" : selectedId})
            };
            //Get push token of the selected driver
            fetch('https://magicdjangoapp.herokuapp.com/pushtokens/push_token/', specifications)
            .then(response => response.json())
            .then(jsonResponse => {
                //Message to be send to a driver via a notification
                const message = {
                    to: jsonResponse[0].token[0].trim(),
                    sound : 'default',
                    title: 'Ride Request',
                    body: 'Someone has requested a ride',
                    data: {phone: phoneNumber, pickupLat: latitude, pickupLong: longitude}
                };
                //Making a POST request to Expo API to handle the notification
                fetch('https://exp.host/--/api/v2/push/send', {
                    method: 'POST',
                    headers: {
                        Accept: 'application/json',
                        'Accept-encoding': 'gzip, deflate',
                        'Content-Type': 'application/json',
                    },
                    body: JSON.stringify(message),
                })
                .catch(error => console.log("Call 2 error: " + error));
            })
            .catch(error => console.log("Call 3 error: " + error));
            props.navProp.navigate("Passenger Home", {userProp: phoneNumber});
        }
        //----------------------------------------------------------------------------------------------------
    }

    const filterBy = (filter) => {
        if(filter.id === 1){
            addDriver([]);
            let specifications = {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json;charset=utf-8'
                },
                body: JSON.stringify(params)
            }
            fetch("https://magicdjangoapp.herokuapp.com/friends/available_friends/", specifications)
                .then(response => response.json())
                .then(jsonResponse => {
                    jsonResponse.forEach(object => {
                        Object.entries(object).forEach(([key, value]) => {
                            if(key === 'first_name'){
                                firstName = value;
                                firstName = firstName.trim();
                            }
                            if(key === 'last_name'){
                                lastName = value;
                                lastName = lastName.trim();
                            }
                            if(key === 'phone'){
                                id = value;
                            }
                            name = firstName + ' ' + lastName;
                            currentDriver = {name, id};
                            addDriver((prevDrivers) => {
                                return [...prevDrivers.filter(driver => driver.id != id), currentDriver]
                            });
                        });
                    });
                    setDriversLoaded(true);
                })
                .catch(error => console.log("Call 4 error: "+error))
        }

        if(filter.id === 2){
            addDriver([]);
            let specifications = {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json;charset=utf-8'
                },
                body: JSON.stringify(params)
            }
            fetch("https://magicdjangoapp.herokuapp.com/friends/available_other/", specifications)
                .then(response => response.json())
                .then(jsonResponse => {
                    jsonResponse.forEach(object => {
                        Object.entries(object).forEach(([key, value]) => {
                            if(key === 'first_name'){
                                firstName = value;
                                firstName = firstName.trim();
                            }
                            if(key === 'last_name'){
                                lastName = value;
                                lastName = lastName.trim();
                            }
                            if(key === 'phone'){
                                id = value;
                            }
                            name = firstName + ' ' + lastName;
                            currentDriver = {name, id};
                            addDriver((prevDrivers) => {
                                return [...prevDrivers.filter(driver => driver.id != id), currentDriver]
                            });
                        });
                    });
                    setDriversLoaded(true);
                })
                .catch(error => console.log("Call 5 error: "+error))
        }
        if(filter.id === 3){
            addDriver([]);
            let specifications = {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json;charset=utf-8'
                },
                body: JSON.stringify(dateAndTime)
            }
            fetch("https://magicdjangoapp.herokuapp.com/driverschedule/available_drivers/", specifications)
                .then(response => response.json())
                .then(jsonResponse => {
                    jsonResponse.forEach(object => {
                        Object.entries(object).forEach(([key, value]) => {
                            if(key === 'first_name'){
                                firstName = value;
                                firstName = firstName.trim();
                            }
                            if(key === 'last_name'){
                                lastName = value;
                                lastName = lastName.trim();
                            }
                            if(key === 'phone'){
                                id = value;
                            }
                            name = firstName + ' ' + lastName;
                            currentDriver = {name, id};    
                            addDriver((prevDrivers) => {
                                return [...prevDrivers.filter(driver => driver.id != id), currentDriver]
                            });
                        });
                    });
                    setDriversLoaded(true);
                })
                .catch(error => console.log("Call 6 error: "+error))
        }
    }

  return (
    <View style={Styles.container}>
        <Text style={{ marginVertical: 16, width: '100%', textAlign: 'center', fontSize: 18, fontWeight: '500'}}>Please choose a filter below: </Text>
        <View style={Styles.tripPlannerContainer}>
            <StatusBar
                backgroundColor="#F2F2F7"
                barStyle='dark-content'>
            </StatusBar>

            <View style={Styles.filterButtonView}>
                <FlatList 
                    numColumns={3}
                    contentContainerStyle={{width: '100%'}}
                    data={filter}
                    renderItem={renderFilterButton}
                    keyExtractor={(item) => item.id}
                    extraData={filterId}
                /> 
            </View>

            <View style={Styles.driverSelectionTextView}>
                <Text style={{ fontSize: 18, fontWeight: '500', textAlign: 'center', }}>
                    Please choose a driver to transport you:
                </Text>
            </View>
            <View style={Styles.driverListView}>
                <FlatList 
                    contentContainerStyle={{width: '100%'}}
                    data={driver}
                    renderItem={renderItem}
                    keyExtractor={(item) => item.id}
                    extraData={selectedId}
                />            
            </View>
        </View>

        <View style={{flex: 2, backgroundColor: 'white', borderTopLeftRadius: 24, borderTopRightRadius: 24, alignItems: 'center'}}>
                <View style={{ flex: 1, justifyContent: 'flex-start', marginTop: 12, width: '90%'}}>
                    <View style={{ flex: 1, marginBottom: 16, flexDirection: 'row'}}>
                        <Text style={{ flex: 2, fontSize: 18, fontWeight: '700', color: '#6394ff'}}>{selectedDriver["name"]} </Text>
                        <Text style={{ flex: 1, fontSize: 16, color: '#4c83fc'}}>{formattedDate}</Text>
                        <Text style={{ flex: 1, fontSize: 16, color: '#4c83fc', textAlign: 'right'}}>{formattedTime}</Text>
                    </View>
                    <View style={{flex: 1, flexDirection: 'row'}}>
                        <Text style={{ flex: 1, fontSize: 16}}>From: </Text>
                        <View style={{flex: 3}}>
                        <ScrollView horizontal={true} showsHorizontalScrollIndicator={true} style={{flex: 1}}>
                            <Text style={{ fontSize: 16, color: '#4c83fc'}}>{startingFrom}</Text>
                        </ScrollView>
                        </View>
                    </View>
                    <View style={{flex: 1, flexDirection: 'row'}}>
                        <Text style={{ flex: 1, fontSize: 16}}>To: </Text>
                        <View style={{flex: 3}}>
                            <ScrollView horizontal={true} showsHorizontalScrollIndicator={true} style={{flex: 1}}>
                                <Text style={{ fontSize: 16, color: '#4c83fc'}}>{destinationTo}</Text>
                            </ScrollView>
                        </View>
                    </View>
                </View>
            <View style={Styles.submitBtnContainer}>
                <View style={{flex: 1, alignItems: 'center'}}>
                    <TouchableOpacity 
                        style={Styles.backButton} 
                        onPress={()=>props.navProp.goBack()}>
                        <Entypo name="arrow-bold-left" size={20} color="white" style={Styles.backIcon} />
                        <Text style={[Styles.buttonText, {marginLeft: 0, fontSize: 18}]}> Date & Time</Text>
                    </TouchableOpacity>
                </View>
                <View style={{flex: 1, alignItems: 'center'}}>
                    <TouchableOpacity 
                        style={Styles.submitRequestBtn} 
                        onPress={()=>submitRequest(driver)}>
                        <Text style={[Styles.buttonText, { marginLeft: 0, fontSize: 18}]}>Request</Text>
                        <MaterialIcons name="send" size={20} color="white" style={Styles.submitIcon} />
                    </TouchableOpacity>
                </View>
            </View>
        </View>
    </View>
  );
}